"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _tape = require("tape");

var _tape2 = _interopRequireDefault(_tape);

var _postcss = require("postcss");

var _postcss2 = _interopRequireDefault(_postcss);

var _disableRanges = require("../disableRanges");

var _disableRanges2 = _interopRequireDefault(_disableRanges);

(0, _tape2["default"])("registers disable/enable commands without rules", function (t) {
  t.plan(4);

  testDisableRanges("a {}", function (result) {
    t.deepEqual(result.disabledRanges, []);
  });

  testDisableRanges("/* stylelint-disable */\na {}", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 1 }]);
  });

  testDisableRanges("a {}\n" + "/* stylelint-disable */\n" + "b {}\n" + "/* stylelint-enable */\n" + ".foo {}", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 2, end: 4 }]);
  });

  testDisableRanges("a {}\n" + "/* stylelint-disable */\n" + "b {}\n" + "/* stylelint-enable */\n" + ".foo {}\n" + "/* stylelint-disable */\n" + "b {}\n" + "/* stylelint-enable */\n" + ".foo {}", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 2, end: 4 }, { start: 6, end: 8 }]);
  });
});

(0, _tape2["default"])("registers disable/enable commands with rules", function (t) {
  t.plan(3);

  testDisableRanges("/* stylelint-disable foo-bar */\na {}", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 1, rules: ["foo-bar"] }]);
  });

  testDisableRanges("a {}\n" + "/* stylelint-disable foo-bar */\n" + "b {}\n" + "/* stylelint-enable */\n" + ".foo {}\n" + "/* stylelint-disable foo-bar,baz-maz */\n" + "b {}\n" + "/* stylelint-enable */\n" + ".foo {}", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 2, end: 4, rules: ["foo-bar"] }, { start: 6, end: 8, rules: ["foo-bar", "baz-maz"] }]);
  });

  testDisableRanges("/* stylelint-disable foo-bar, hoo-hah,\n\tslime */\n" + "b {}\n", function (result) {
    t.deepEqual(result.disabledRanges, [{ start: 1, rules: ["foo-bar", "hoo-hah", "slime"] }]);
  });
});

function testDisableRanges(source, cb) {
  (0, _postcss2["default"])().use(_disableRanges2["default"]).process(source).then(cb)["catch"](function (err) {
    throw err;
  });
}