"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _postcss = require("postcss");

var _postcss2 = _interopRequireDefault(_postcss);

var _tape = require("tape");

var _tape2 = _interopRequireDefault(_tape);

var _ = require("..");

var _2 = _interopRequireDefault(_);

var warnAboutFooMessages = _2["default"].utils.ruleMessages("warn-about-foo", {
  found: "found .foo",
  notFound: "never found .foo"
});

function warnAboutFoo(expectation) {
  return function (root, result) {
    var foundFoo = undefined;
    root.eachRule(function (rule) {
      if (rule.selector === ".foo") {
        if (expectation === "always") {
          _2["default"].utils.report({
            result: result,
            ruleName: "warn-about-foo",
            message: warnAboutFooMessages.found,
            node: rule
          });
          foundFoo = true;
        }
      }
    });
    if (!foundFoo) {
      _2["default"].utils.report({
        result: result,
        line: 1,
        ruleName: "warn-about-foo",
        message: warnAboutFooMessages.notFound
      });
    }
  };
}

var cssA = ".foo {}";

var cssB = ".bar {}";

var configA = {
  plugins: {
    "warn-about-foo": warnAboutFoo
  },
  rules: {
    "warn-about-foo": [2, "always"],
    "block-no-empty": 2
  }
};

(0, _tape2["default"])("plugin runs", function (t) {
  t.plan(6);

  var processor = (0, _postcss2["default"])().use((0, _2["default"])(configA));

  processor.process(cssA).then(function (result) {
    t.equal(result.warnings().length, 2);
    t.equal(result.warnings()[0].text, "found .foo (warn-about-foo)");
    t.ok(result.warnings()[0].node);
  })["catch"](function (e) {
    return console.log(e.stack);
  });

  processor.process(cssB).then(function (result) {
    t.equal(result.warnings().length, 2);
    t.equal(result.warnings()[0].text, "never found .foo (warn-about-foo)");
    t.notOk(result.warnings()[0].node);
  })["catch"](function (e) {
    return console.log(e.stack);
  });
});

var configB = {
  plugins: {
    linterSet: {
      warnAboutFoo: warnAboutFoo
    }
  },
  rules: {
    warnAboutFoo: [2, "always"],
    "block-no-empty": 2
  }
};

(0, _tape2["default"])("plugin within set runs", function (t) {
  t.plan(2);

  var processor = (0, _postcss2["default"])().use((0, _2["default"])(configB));

  processor.process(cssA).then(function (result) {
    t.equal(result.warnings().length, 2);
    t.equal(result.warnings()[0].text, "found .foo (warn-about-foo)");
  });
});