"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

function sharedAlwaysTests(tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {} b {}", "rule ignored");
  tr.ok("@font-face {}", "first node ignored");
  tr.ok("a {}\n\n@media {}");
  tr.ok("@keyframes foo {}\n\n@media {}");
  tr.ok("a {}\r\n\r\n@media {}", "windows");

  tr.notOk("a {} @media {}", _.messages.expected);
  tr.notOk("@keyframes foo {} @media {}", _.messages.expected);
  tr.notOk("a {}\n@media {}", _.messages.expected);
  tr.notOk("a {}\r\n@media {}", _.messages.expected);
  tr.notOk("a {}\n\n/* comment */\n@media {}", _.messages.expected);
  tr.notOk("a {}\r\n\r\n/* comment */\r\n@media {}", _.messages.expected);
}

testRule("always", function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n\n  @mixin foo;\n}");
});

testRule("always", { except: ["blockless-group"] }, function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n\n  @mixin foo;\n}");

  tr.ok("@keyframes foo {}\n\n@import 'x.css'", "empty line not blockless pair");
  tr.ok("@import 'x.css';\n@import 'y.css'", "no empty line blockless pair");
  tr.ok("@import 'x.css';", "single blockless rule");

  tr.notOk("@keyframes foo {}\n@import 'x.css'", _.messages.expected);
  tr.notOk("@import 'x.css';\n\n@import 'y.css'", _.messages.rejected);
});

testRule("always", { except: ["all-nested"] }, function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n  color: pink;\n  @mixin foo;\n}");

  tr.notOk("a {\n\n  @mixin foo;\n  color: pink;\n}", _.messages.rejected);
  tr.notOk("a {\n\n  color: pink;\n\n  @mixin foo;\n}", _.messages.rejected);
});

testRule("always", { except: ["first-nested"] }, function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n  @mixin foo;\n  color: pink;\n}");

  tr.notOk("a {\n  color: pink;\n  @mixin foo;\n}", _.messages.expected);
  tr.notOk("a {\n\n  @mixin foo;\n  color: pink;\n}", _.messages.rejected);
});

testRule("always", { ignore: ["all-nested"] }, function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n  color: pink;\n  @mixin foo;\n}");
  tr.ok("a {\n\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n\n  color: pink;\n\n  @mixin foo;\n}");
});

testRule("always", { except: ["blockless-group", "all-nested"] }, function (tr) {
  sharedAlwaysTests(tr);

  tr.ok("a {\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n  color: pink;\n  @mixin foo;\n}");
  tr.ok("@keyframes foo {}\n\n@import 'x.css'", "empty line not blockless pair");
  tr.ok("@import 'x.css';\n@import 'y.css'", "no empty line blockless pair");
  tr.ok("@import 'x.css';", "single blockless rule");

  tr.notOk("@keyframes foo {}\n@import 'x.css'", _.messages.expected);
  tr.notOk("@import 'x.css';\n\n@import 'y.css'", _.messages.rejected);
  tr.notOk("a {\n\n  @mixin foo;\n  color: pink;\n}", _.messages.rejected);
  tr.notOk("a {\n\n  color: pink;\n\n  @mixin foo;\n}", _.messages.rejected);

  tr.ok("a {\n  @mixin foo;\n  @mixin bar;\n}");
});

function sharedNeverTests(tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {}\n\nb {}", "rule ignored");
  tr.ok("\n\n@font-face {}", "first node ignored");
  tr.ok("a {}\n@media {}");
  tr.ok("a {} @media {}");
  tr.ok("@keyframes foo {}\n@media {}");
  tr.ok("@keyframes foo {} @media {}");

  tr.notOk("a {}\n\n@media {}", _.messages.rejected);
  tr.notOk("@keyframes foo {}\n/* comment */\n\n@media {}", _.messages.rejected);
}

testRule("never", function (tr) {
  sharedNeverTests(tr);
  tr.ok("a {\n  @mixin foo;\n}");
});

testRule("never", { except: ["blockless-group"] }, function (tr) {
  sharedNeverTests(tr);
  tr.ok("a {\n  @mixin foo;\n}");

  tr.ok("@keyframes foo {}\n@import 'x.css'", "no empty line not blockless pair");
  tr.ok("@import 'x.css';\n\n@import 'y.css'", "empty line blockless pair");
  tr.ok("@import 'x.css';", "single blockless rule");

  tr.notOk("@keyframes foo {}\n\n@import 'x.css'", _.messages.rejected);
  tr.notOk("@import 'x.css';\n@import 'y.css'", _.messages.expected);
});

testRule("never", { except: ["all-nested"] }, function (tr) {
  sharedNeverTests(tr);

  tr.ok("a {\n\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n  color: pink;\n\n  @mixin foo;\n}");

  tr.notOk("a {\n  @mixin foo;\n  color: pink;\n}", _.messages.expected);
  tr.notOk("a {\n\n  color: pink;\n  @mixin foo;\n}", _.messages.expected);
});

testRule("never", { except: ["first-nested"] }, function (tr) {
  sharedNeverTests(tr);

  tr.ok("a {\n\n  @mixin foo;\n  color: pink;\n}");

  tr.notOk("a {\n  color: pink;\n\n  @mixin foo;\n}", _.messages.rejected);
  tr.notOk("a {\n  @mixin foo;\n  color: pink;\n}", _.messages.expected);
});

testRule("never", { ignore: ["all-nested"] }, function (tr) {
  sharedNeverTests(tr);

  tr.ok("a {\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n  color: pink;\n  @mixin foo;\n}");
  tr.ok("a {\n\n  @mixin foo;\n  color: pink;\n}");
  tr.ok("a {\n\n  color: pink;\n\n  @mixin foo;\n}");
});