"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }\nb { color: red; }");
  tr.ok("a { color: pink; }\r\nb { color: red; }", "CRLF");
  tr.ok("a { color: pink;}\n\t\tb { color: red;}");
  tr.ok("a { color: pink;}\r\n\t\tb { color: red;}", "CRLF");
  tr.ok("a { @extend foo; color: pink; }");
  tr.ok("a { @extend foo; /* comment */\ncolor: pink;  }");

  // Ignores nested closing braces
  tr.ok("@media print { a { color: pink; }\nb { color: red; }}");
  tr.ok("@media print { a { color: pink; }}\n@media screen { b { color: red; }}");

  tr.notOk("a { color: pink; }b { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; } b { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; }  b { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; }\tb { color: red; }", _.messages.expectedAfter());
  tr.notOk("@media print { a { color: pink; } b { color: red; }}", _.messages.expectedAfter());
  tr.notOk("@media print { a { color: pink; }} @media screen { b { color: red; }}", _.messages.expectedAfter());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }\nb { color: red; }");
  tr.ok("a { color: pink; }\r\nb { color: red; }", "CRLF");
  tr.ok("a { color: pink;}\n\t\tb { color: red;}");
  tr.ok("a { color: pink;}\r\n\t\tb { color: red;}", "CRLF");

  // Ignores nested closing braces
  tr.ok("@media print { a { color: pink; }\nb { color: red; }}");
  tr.ok("@media print { a { color: pink; }}\n@media screen { b { color: red; }}");

  // Ignore multi-line
  tr.ok("a { color: pink;\ntop: 0; }b { color: red; }");
  tr.ok("a { color: pink;\ntop: 0;}b { color: red;}");
  tr.ok("a { color: pink;\r\ntop: 0;}b { color: red;}", "CRLF");

  tr.notOk("a { color: pink; }b { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink; } b { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink; }  b { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink; }\tb { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; } b { color: red; }}", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }} @media screen { b { color: red; }}", _.messages.expectedAfterSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }b { color: red; }");
  tr.ok("a { color: pink;}b { color: red;}");

  // Ignores nested closing braces
  tr.ok("@media print { a { color: pink; }b { color: red; }}");
  tr.ok("@media print { a { color: pink; }}@media screen { b { color: red; }}");

  // Ignore multi-line
  tr.ok("a { color: pink;\ntop: 0; }\nb { color: red; }");
  tr.ok("a { color: pink;\ntop: 0;} b { color: red;}");

  tr.notOk("a { color: pink; }\nb { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink; } b { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink; }  b { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink; }\tb { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }\nb { color: red; }}", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }}\n @media screen { b { color: red; }}", _.messages.rejectedAfterSingleLine());
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0; }");
  tr.ok("a { color: pink;\ntop: 0; }\nb { color: red; }");
  tr.ok("a { color: pink;\r\ntop: 0; }\r\nb { color: red; }", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;}\n\t\tb { color: red;}");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink; }\nb { color: red; }}");
  tr.ok("@media print { a {\ncolor: pink; }}\n@media screen { b { color: red; }}");

  // Ignore single-line
  tr.ok("a { color: pink; }\nb { color: red; }");
  tr.ok("a { color: pink; }b { color: red;}");

  tr.notOk("a { color: pink;\ntop: 0; }b { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0; }b { color: red; }", _.messages.expectedAfterMultiLine(), "CRLF");
  tr.notOk("a { color: pink;\ntop: 0; } b { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; }  b { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; }\tb { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; } b { color: red; }}", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }} @media screen { b {\ncolor: red; }}", _.messages.expectedAfterMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0; }");
  tr.ok("a { color: pink;\ntop: 0; }b { color: red; }");
  tr.ok("a { color: pink;\ntop: 0;}b { color: red;}");
  tr.ok("a { color: pink;\r\ntop: 0;}b { color: red;}", "CRLF");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink; }b { color: red; }}");
  tr.ok("@media print { a {\ncolor: pink; }}@media screen { b { color: red; }}");
  tr.ok("@media print { a {\r\ncolor: pink; }}@media screen { b { color: red; }}", "CRLF");

  // Ignore single-line
  tr.ok("a { color: pink; }\nb { color: red; }");
  tr.ok("a { color: pink; }\r\nb { color: red; }", "CRLF");
  tr.ok("a { color: pink;} b { color: red;}");

  tr.notOk("a { color: pink;\ntop: 0; }\nb { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0; }\r\nb { color: red; }", _.messages.rejectedAfterMultiLine(), "CRLF");
  tr.notOk("a { color: pink;\ntop: 0; } b { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; }  b { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; }\tb { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }\nb { color: red; }}", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }}\n@media screen { b {\ncolor: red; }}", _.messages.rejectedAfterMultiLine());
});