"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\n}");
  tr.ok("a { color: pink;\r\n}", "CRLF");
  tr.ok("a { color: pink;\n\t\t}");
  tr.ok("a { color: pink;\n} b { color: red;\n}");
  tr.ok("a { color: pink;\n}b { color: red;\n}");

  tr.ok("@media print {\n  a {\n     color: pink;\n  }\n}", "indentation after the newline before the closing braces");
  tr.ok("@media print {\n\ta {\n\t\tcolor: pink;\n\t\t{\n\t\t\t&:hover;\n\t\t\t}\n\t\t}\n}", "3 level deep nesting with indentation after the newline before the closing braces");

  tr.notOk("a { color: pink;}", _.messages.expectedBefore());
  tr.notOk("a { color: pink; }", _.messages.expectedBefore());
  tr.notOk("a { color: pink; \n}", _.messages.expectedBefore());
  tr.notOk("a { color: pink; \r\n}", _.messages.expectedBefore(), "CRLF");
  tr.notOk("a { color: pink;  }", _.messages.expectedBefore());
  tr.notOk("a { color: pink;\t}", _.messages.expectedBefore());
  tr.notOk("a { color: pink;\n} b { color: red; }", _.messages.expectedBefore());
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0;\n}");
  tr.ok("a { color: pink;\ntop: 0;\n\t\t}");
  tr.ok("a { color: pink;\r\ntop: 0;\r\n\t\t}", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;\n} b { color: red;\n}");
  tr.ok("a { color: pink;\ntop: 0;\n}b { color: red;\n}");

  // Ignore single-line
  tr.ok("a { color: pink;}");
  tr.ok("a { color: pink;} b { color: red;}");
  tr.ok("a { color: pink;}b { color: red;}");

  tr.notOk("a { color: pink;\ntop: 0;}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0;}", _.messages.expectedBeforeMultiLine(), "CRLF");
  tr.notOk("a { color: pink;\ntop: 0; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; \n}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;  }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;\t}", _.messages.expectedBeforeMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0;}");
  tr.ok("a { color: pink;\r\ntop: 0;}", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;} b { color: red;\ntop: 0;}");
  tr.ok("a { color: pink;\ntop: 0;}b { color: red;\ntop: 0;}");

  // Ignore single-line
  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink;\t}");
  tr.ok("a { color: pink;  }");

  tr.notOk("a { color: pink;\ntop: 0; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0; }", _.messages.rejectedBeforeMultiLine(), "CRLF");
  tr.notOk("a { color: pink;\ntop: 0;\n}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;  }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;\t}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;} b { color: red;\ntop: 0;\n}", _.messages.rejectedBeforeMultiLine());
});