"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; } b { color: red; }");
  tr.ok("a { color: pink;} b { color: red;}");
  tr.ok("@media print { a { color: pink; } b { color: red; } }");
  tr.ok("@media print { a { color: pink; } } @media screen { b { color: red; } }");
  tr.ok("@import 'foo.css';\n@import 'bar.css';", "two blockless statements");

  // Ignores nested closing braces
  tr.ok("@media print { a { color: pink; } b { color: red; }}");
  tr.ok("@media print { a { color: pink; }} @media screen { b { color: red; }}");

  tr.notOk("a { color: pink; }b { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; }  b { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; }\nb { color: red; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink; }\r\nb { color: red; }", _.messages.expectedAfter(), "CRLF");
  tr.notOk("a { color: pink; }\tb { color: red; }", _.messages.expectedAfter());
  tr.notOk("@media print { a { color: pink; }b { color: red; }}", _.messages.expectedAfter());
  tr.notOk("@media print { a { color: pink; }}@media screen { b { color: red; }}", _.messages.expectedAfter());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }b { color: red; }");
  tr.ok("a { color: pink;}b { color: red;}");

  // Ignores nested closing braces
  tr.ok("@media print { a { color: pink; }b { color: red; } }");
  tr.ok("@media print { a { color: pink; } }@media screen { b { color: red; } }");

  tr.notOk("a { color: pink; } b { color: red; }", _.messages.rejectedAfter());
  tr.notOk("a { color: pink; }  b { color: red; }", _.messages.rejectedAfter());
  tr.notOk("a { color: pink; }\nb { color: red; }", _.messages.rejectedAfter());
  tr.notOk("a { color: pink; }\r\nb { color: red; }", _.messages.rejectedAfter(), "CRLF");
  tr.notOk("a { color: pink; }\tb { color: red; }", _.messages.rejectedAfter());
  tr.notOk("@media print { a { color: pink; } b { color: red; }}", _.messages.rejectedAfter());
  tr.notOk("@media print { a { color: pink; }} @media screen { b { color: red; }}", _.messages.rejectedAfter());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; background: orange; }");
  tr.ok("a { color: pink; background: orange; } b { color: red; }");
  tr.ok("a { color: pink; background: orange;} b { color: red;}");

  // Ignore multi line
  tr.ok("a { color:\npink;}");
  tr.ok("a { color:\r\npink;}", "CRLF");
  tr.ok("a { color:\npink;}b { color: red; }");
  tr.ok("a { color:\npink;}b { color:\nred;}");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink; } b { color: red;}}");
  tr.ok("@media print { a {\ncolor: pink; }} @media screen { b { color: red;}}");
  tr.ok("@media print { a {\r\ncolor: pink; }} @media screen { b { color: red;}}", "CRLF");

  tr.notOk("a { color: pink; background: orange;}b { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink; background: orange;}  b { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink; background: orange;}\tb { color: red; }", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }b { color: red; }}", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }}@media screen { b { color: red; }}", _.messages.expectedAfterSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; background: orange; }");
  tr.ok("a { color: pink; background: orange; }b { color: red; }");
  tr.ok("a { color: pink; background: orange;}b { color: red;}");

  // Ignore multi line
  tr.ok("a { color:\npink;}");
  tr.ok("a { color:\r\npink;}", "CRLF");
  tr.ok("a { color:\npink;} b { color: red; }");
  tr.ok("a { color:\npink;} b { color:\nred;}");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink;} b { color: red;} }");
  tr.ok("@media print { a {\r\ncolor: pink;} b { color: red;} }", "CRLF");
  tr.ok("@media print { a {\ncolor: pink;} } @media screen { b { color: red;} }");

  tr.notOk("a { color: pink; background: orange;} b { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink; background: orange;}  b { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink; background: orange;}\tb { color: red; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; } b { color: red; }}", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print { a { color: pink; }} @media screen { b { color: red; }}", _.messages.rejectedAfterSingleLine());
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\nbackground: orange; }");
  tr.ok("a { color: pink;\r\nbackground: orange; }", "CRLF");
  tr.ok("a { color: pink;\nbackground: orange; } b { color: red; }");
  tr.ok("a { color: pink;\nbackground: orange;} b { color: red;}");

  // Ignore single line
  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }b { color: red; }");
  tr.ok("a { color: pink;}b { color: red;}");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink; } b { color: red; }}");
  tr.ok("@media print { a {\r\ncolor: pink; } b { color: red; }}", "CRLF");
  tr.ok("@media print { a {\ncolor: pink; }} @media screen { b { color: red; }}");

  tr.notOk("a { color: pink;\nbackground: orange;}b { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\nbackground: orange;}  b { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\nbackground: orange;}\nb { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a { color: pink;\r\nbackground: orange;}\r\nb { color: red; }", _.messages.expectedAfterMultiLine(), "CRLF");
  tr.notOk("a { color: pink;\nbackground: orange;}\tb { color: red; }", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }b { color: red; }}", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }}@media screen { b {\ncolor: red; }}", _.messages.expectedAfterMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\nbackground: orange; }");
  tr.ok("a { color: pink;\r\nbackground: orange; }", "CRLF");
  tr.ok("a { color: pink;\nbackground: orange; }b { color: red; }");
  tr.ok("a { color: pink;\nbackground: orange;}b { color: red;}");

  // Ignore single line
  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; } b { color: red; }");
  tr.ok("a { color: pink;} b { color: red;}");

  // Ignores nested closing braces
  tr.ok("@media print { a {\ncolor: pink; }b { color: red; } }");
  tr.ok("@media print { a {\r\ncolor: pink; }b { color: red; } }", "CRLF");
  tr.ok("@media print { a {\ncolor: pink; }}@media screen { b { color: red; } }");

  tr.notOk("a { color: pink;\nbackground: orange;} b { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\nbackground: orange;}  b { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\nbackground: orange;}\nb { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a { color: pink;\nbackground: orange;}\tb { color: red; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; } b { color: red; }}", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print { a {\ncolor: pink; }} @media screen { b {\ncolor: red; }}", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print { a {\r\ncolor: pink; }} @media screen { b {\r\ncolor: red; }}", _.messages.rejectedAfterMultiLine(), "CRLF");
});