"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; } b { color: red; }");
  tr.ok("a { color: pink; }b { color: red; }");

  tr.notOk("a { color: pink;}", _.messages.expectedBefore());
  tr.notOk("a { color: pink;  }", _.messages.expectedBefore());
  tr.notOk("a { color: pink;\n}", _.messages.expectedBefore());
  tr.notOk("a { color: pink;\r\n}", _.messages.expectedBefore(), "CRLF");
  tr.notOk("a { color: pink;\t}", _.messages.expectedBefore());
  tr.notOk("a { color: pink; } b { color: red;}", _.messages.expectedBefore());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;}");
  tr.ok("a { color: pink;} b { color: red;}");
  tr.ok("a { color: pink;}b { color: red;}");

  tr.notOk("a { color: pink; }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink;  }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink;\n}", _.messages.rejectedBefore());
  tr.notOk("a { color: pink;\r\n}", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("a { color: pink;\t}", _.messages.rejectedBefore());
  tr.notOk("a { color: pink;} b { color: red; }", _.messages.rejectedBefore());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; } b { color: red; }");
  tr.ok("a { color: pink; }b { color: red; }");
  tr.ok("a,\nb { color: pink; } c { color: red; }", "multi-line rule, single-line block");

  // Ignore multi-line
  tr.ok("a { color: pink;\ntop: 0;}");
  tr.ok("a { color: pink;\n\ntop: 0;}", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;  } b { color: red; }");
  tr.ok("a { color: pink;\ntop: 0;\n}b { color: red; }");

  tr.notOk("a { color: pink;}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,\nb { color: pink;}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,\r\nb { color: pink;}", _.messages.expectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { color: pink;  }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { color: pink;\t}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { color: pink; } b { color: red;}", _.messages.expectedBeforeSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;}");
  tr.ok("a { color: pink;} b { color: red;}");
  tr.ok("a { color: pink;}b { color: red;}");
  tr.ok("a,\nb { color: pink;} b { color: red;}", "multi-line rule, single-line block");

  // Ignore multi-line
  tr.ok("a { color: pink;\ntop: 0; }");
  tr.ok("a { color: pink;\r\ntop: 0; }", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;  } b { color: red;}");
  tr.ok("a { color: pink;\ntop: 0;\n}b { color: red;}");

  tr.notOk("a { color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a,\nb { color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a,\r\nb { color: pink; }", _.messages.rejectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { color: pink;  }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { color: pink;\t}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { color: pink;} b { color: red;\t}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { color: pink;  } b { color: red;}", _.messages.rejectedBeforeSingleLine());
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0; }");
  tr.ok("a { color: pink;\ntop: 0; } b { color: red; }");
  tr.ok("a { color: pink;\ntop: 0; }b { color: red; }");
  tr.ok("a { color: pink;\r\ntop: 0; }b { color: red; }", "CRLF");

  // Ignore single-line
  tr.ok("a { color: pink;}");
  tr.ok("a { color: pink;  } b { color: red; }");
  tr.ok("a { color: pink;\t}b { color: red; }");

  tr.notOk("a { color: pink;\ntop: 0;}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;  }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;\t}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink; } b { color: red;\ntop: 0;}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;} b { color: red; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0;} b { color: red; }", _.messages.expectedBeforeMultiLine(), "CRLF");
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\ntop: 0;}");
  tr.ok("a { color: pink;\ntop: 0;} b { color: red;}");
  tr.ok("a { color: pink;\r\ntop: 0;} b { color: red;}", "CRLF");
  tr.ok("a { color: pink;\ntop: 0;}b { color: red;}");

  // Ignore single-line
  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink;  } b { color: red; }");
  tr.ok("a { color: pink;\t}b { color: red; }");

  tr.notOk("a { color: pink;\ntop: 0; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;  }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0;\t}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\r\ntop: 0;\t}", _.messages.rejectedBeforeMultiLine(), "CRLF");
  tr.notOk("a { color: pink; } b { color: red;\ntop: 0; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { color: pink;\ntop: 0; } b { color: red; }", _.messages.rejectedBeforeMultiLine());
});