"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@import url(x.css)");
  tr.ok("a {\ncolor: pink; }");
  tr.ok("a {\r\ncolor: pink; }", "CRLF");
  tr.ok("a{\ncolor: pink; }");
  tr.ok("a{\n\tcolor: pink; }");
  tr.ok("a{\n  color: pink; }");
  tr.ok("a{\r\n  color: pink; }", "CRLF");
  tr.ok("@media print {\na {\ncolor: pink; } }");
  tr.ok("@media print{\na{\ncolor: pink; } }");
  tr.ok("@media print{\r\na{\r\ncolor: pink; } }", "CRLF");
  tr.ok("@media print{\n\ta{\n  color: pink; } }");
  tr.ok("a { /* 1 */\n  color: pink;\n}", "end-of-line comment");
  tr.ok("a {\n  /* 1 */\n  color: pink;\n}", "next-line comment");
  tr.ok("a {\r\n  /* 1 */\r\n  color: pink;\r\n}", "next-line comment and CRLF");

  tr.notOk("a { color: pink; }", _.messages.expectedAfter());
  tr.notOk("a {color: pink; }", _.messages.expectedAfter());
  tr.notOk("a {  color: pink; }", _.messages.expectedAfter());
  tr.notOk("a {\tcolor: pink; }", _.messages.expectedAfter());
  tr.notOk("@media print { a {\ncolor: pink; } }", _.messages.expectedAfter());
  tr.notOk("@media print {\na { color: pink; } }", _.messages.expectedAfter());
  tr.notOk("@media print {\r\na { color: pink; } }", _.messages.expectedAfter(), "CRLF");
  tr.notOk("a {  /* 1 */\n  color: pink;\n}", _.messages.expectedAfter(), "end-of-line comment with two spaces before");
  tr.notOk("a {  /* 1 */\r\n  color: pink;\r\n}", _.messages.expectedAfter(), "end-of-line comment with two spaces before and CRLF");
  tr.notOk("a { /* 1 */ color: pink; }", _.messages.expectedAfter(), "next node is comment without newline after");
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // Regular "always" tests
  tr.ok("a {\ncolor: pink; }");
  tr.ok("a {\n  color: pink;\n  background: orange; }");
  tr.ok("a {\r\n  color: pink;\r\n  background: orange; }", "CRLF");
  tr.ok("a{\ncolor: pink; }");
  tr.ok("a{\n\tcolor: pink; }");
  tr.ok("a{\n  color: pink; }");
  tr.ok("@media print {\na {\ncolor: pink; } }");
  tr.ok("@media print {\r\na {\r\ncolor: pink; } }", "CRLF");
  tr.ok("@media print{\na{\ncolor: pink; } }");
  tr.ok("@media print{\n\ta{\n  color: pink; } }");
  tr.ok("@media print{\r\n\ta{\r\n  color: pink; } }", "CRLF");

  tr.notOk("a { color: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {color: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {  color: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\r\nbackground: orange; }", _.messages.expectedAfterMultiLine(), "CRLF");
  tr.notOk("@media print { a {\ncolor:\npink; } }", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print {\na { color:\npink; } }", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print {\r\na { color:\r\npink; } }", _.messages.expectedAfterMultiLine(), "CRLF");

  // Ignore single-line
  tr.ok("a { color: pink; }");
  tr.ok("a {\tcolor: pink; }");
  tr.ok("a {  color: pink;  background: orange; }");
  tr.ok("a { /* 1 */ color: pink; }");
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {color: pink;\nbackground: orange; }");
  tr.ok("a {color: pink;\r\nbackground: orange; }", "CRLF");
  tr.ok("a{color: pink;\nbackground: orange; }");
  tr.ok("@media print {a {color: pink;\nbackground: orange; } }");
  tr.ok("@media print{a{color: pink;\nbackground: orange; } }");

  // Ignore single-line
  tr.ok("a { color: pink; }");
  tr.ok("a {  color: pink; }");
  tr.ok("a {\tcolor: pink; }");
  tr.ok("@media print { a { color: pink; } }");
  tr.ok("@media print {\ta {\tcolor: pink; } }");

  tr.notOk("a { color: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {\ncolor: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {\r\ncolor: pink;\r\nbackground: orange; }", _.messages.rejectedAfterMultiLine(), "CRLF");
  tr.notOk("a {  color: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print {\na {color: pink;\nbackground: orange; } }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print {a {\ncolor: pink;\nbackground: orange; } }", _.messages.rejectedAfterMultiLine());
});