"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "block-opening-brace-newline-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected newline after \"{\"";
  },
  expectedAfterMultiLine: function expectedAfterMultiLine() {
    return "Expected newline after \"{\" of a multi-line block";
  },
  rejectedAfterMultiLine: function rejectedAfterMultiLine() {
    return "Unexpected whitespace after \"{\" of a multi-line block";
  }
});

/**
 * @param {"always"|"always-multi-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("newline", expectation, messages);

  return function (root, result) {

    // Check both kinds of statement: rules and at-rules
    root.eachRule(check);
    root.eachAtRule(check);

    function check(statement) {

      // Return early if blockless or has empty block
      if (!(0, _utils.cssStatementHasBlock)(statement) || (0, _utils.cssStatementHasEmptyBlock)(statement)) {
        return;
      }

      // Allow an end-of-line comment one space after the brace
      var firstNode = statement.first;
      var nodeToCheck = firstNode.type === "comment" && firstNode.before === " " ? firstNode.next() : firstNode;
      if (!nodeToCheck) {
        return;
      }

      checker.afterOneOnly({
        source: nodeToCheck.toString(),
        index: -1,
        lineCheckStr: (0, _utils.cssStatementBlockString)(statement),
        err: function err(m) {
          (0, _utils.report)({
            message: m,
            node: nodeToCheck,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
};