"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@import url(x.css)");
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");

  tr.notOk("a {color: pink; }", _.messages.expectedAfter());
  tr.notOk("a {  color: pink; }", _.messages.expectedAfter());
  tr.notOk("a {\tcolor: pink; }", _.messages.expectedAfter());
  tr.notOk("a {\ncolor: pink; }", _.messages.expectedAfter());
  tr.notOk("a {\r\ncolor: pink; }", _.messages.expectedAfter(), "CRLF");
  tr.notOk("@media print {\na { color: pink; } }", _.messages.expectedAfter());
  tr.notOk("@media print { a {\ncolor: pink; } }", _.messages.expectedAfter());
  tr.notOk("@media print { a {\r\ncolor: pink; } }", _.messages.expectedAfter(), "CRLF");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {color: pink; }");
  tr.ok("@media print {a {color: pink; } }");

  tr.notOk("a { color: pink; }", _.messages.rejectedAfter());
  tr.notOk("a {  color: pink; }", _.messages.rejectedAfter());
  tr.notOk("a {\tcolor: pink; }", _.messages.rejectedAfter());
  tr.notOk("a {\ncolor: pink; }", _.messages.rejectedAfter());
  tr.notOk("a {\r\ncolor: pink; }", _.messages.rejectedAfter(), "CRLF");
  tr.notOk("@media print {\na {color: pink; } }", _.messages.rejectedAfter());
  tr.notOk("@media print {a {\ncolor: pink; } }", _.messages.rejectedAfter());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // Regular "always" tests
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");

  tr.notOk("a {color: pink; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a {  color: pink; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a {\tcolor: pink; }", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print {\ta { color: pink; } }", _.messages.expectedAfterSingleLine());
  tr.notOk("@media print { a {\tcolor: pink; } }", _.messages.expectedAfterSingleLine());

  // Ignoring multi-line blocks
  tr.ok("a {\ncolor: pink; }");
  tr.ok("a {\r\ncolor: pink; }", "CRLF");
  tr.ok("a {color:\npink; }");
  tr.ok("@media print {a {color:\npink; } }");
  tr.ok("@media print{a {color:\npink; } }");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // Regular "never" tests
  tr.ok("a {color: pink; }");
  tr.ok("@media print {a {color: pink; } }");

  tr.notOk("a { color: pink; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a {  color: pink; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a {\tcolor: pink; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print { a {color: pink; } }", _.messages.rejectedAfterSingleLine());
  tr.notOk("@media print {a { color: pink; } }", _.messages.rejectedAfterSingleLine());

  // Ignoring multi-line blocks
  tr.ok("a { color:\npink; }");
  tr.ok("@media print { a { color:\npink; } }");
  tr.ok("@media print { a\n{color: pink; } }");
  tr.ok("@media print { a\r\n{color: pink; } }", "CRLF");
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\nbackground: orange; }");
  tr.ok("@media print { a { color: pink;\nbackground: orange } }");

  // Ignoring single-line blocks
  tr.ok("a {color: pink; }");
  tr.ok("@media print {a {color: pink; } }");
  tr.ok("a { color: pink; }");
  tr.ok("a {  color: pink; }");
  tr.ok("a {\tcolor: pink; }");

  tr.notOk("a {color: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {  color: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {\ncolor: pink;\nbackground: orange; }", _.messages.expectedAfterMultiLine());
  tr.notOk("a {\r\ncolor: pink;\r\nbackground: orange; }", _.messages.expectedAfterMultiLine(), "CRLF");
  tr.notOk("@media print\n{a { color: pink;\nbackground: orange; } }", _.messages.expectedAfterMultiLine());
  tr.notOk("@media print { a\n{color: pink;\nbackground: orange; } }", _.messages.expectedAfterMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {color: pink;\nbackground: orange; }");
  tr.ok("@media print {a\n{color: pink;\nbackground: orange } }");
  tr.ok("@media print {a\r\n{color: pink;\r\nbackground: orange } }", "CRLF");

  // Ignoring single-line blocks
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");
  tr.ok("a { color: pink; }");
  tr.ok("a {  color: pink; }");
  tr.ok("a {\tcolor: pink; }");

  tr.notOk("a { color: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {  color: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("a {\tcolor: pink;\r\nbackground: orange; }", _.messages.rejectedAfterMultiLine(), "CRLF");
  tr.notOk("a {\ncolor: pink;\nbackground: orange; }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print\n{ a {color: pink;\nbackground: orange; } }", _.messages.rejectedAfterMultiLine());
  tr.notOk("@media print{a\n{ color: pink;\nbackground: orange; } }", _.messages.rejectedAfterMultiLine());
});