"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@import url(x.css)");
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");

  tr.ok("a {{ &:hover { color: pink; }}}");
  tr.ok("a {\n{ &:hover { color: pink; }}}");

  tr.notOk("a{ color: pink; }", _.messages.expectedBefore());
  tr.notOk("a  { color: pink; }", _.messages.expectedBefore());
  tr.notOk("a\t{ color: pink; }", _.messages.expectedBefore());
  tr.notOk("a\n{ color: pink; }", _.messages.expectedBefore());
  tr.notOk("a\r\n{ color: pink; }", _.messages.expectedBefore(), "CRLF");
  tr.notOk("@media print\n{ a { color: pink; } }", _.messages.expectedBefore());
  tr.notOk("@media print { a\n{ color: pink; } }", _.messages.expectedBefore());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a{ color: pink; }");
  tr.ok("@media print{ a{ color: pink; } }");

  tr.notOk("a { color: pink; }", _.messages.rejectedBefore());
  tr.notOk("a  { color: pink; }", _.messages.rejectedBefore());
  tr.notOk("a\t{ color: pink; }", _.messages.rejectedBefore());
  tr.notOk("a\n{ color: pink; }", _.messages.rejectedBefore());
  tr.notOk("a\r\n{ color: pink; }", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("@media print { a{ color: pink; } }", _.messages.rejectedBefore());
  tr.notOk("@media print{ a { color: pink; } }", _.messages.rejectedBefore());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // Regular "always" tests
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");

  tr.notOk("a{ color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a  { color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a\t{ color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a\n{ color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a\r\n{ color: pink; }", _.messages.expectedBeforeSingleLine(), "CRLF");
  tr.notOk("@media print\n{ a { color: pink; } }", _.messages.expectedBeforeSingleLine());
  tr.notOk("@media print { a\n{ color: pink; } }", _.messages.expectedBeforeSingleLine());

  // Ignoring multi-line blocks
  tr.ok("a{ color:\npink; }");
  tr.ok("@media print { a{ color:\npink; } }");
  tr.ok("@media print{ a { color:\npink; } }");
  tr.ok("@media print{\na { color: pink; } }");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // Regular "never" tests
  tr.ok("a{ color: pink; }");
  tr.ok("@media print{ a{ color: pink; } }");

  tr.notOk("a { color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a  { color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a\t{ color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a\n{ color: pink; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a\r\n{ color: pink; }", _.messages.rejectedBeforeSingleLine(), "CRLF");
  tr.notOk("@media print { a{ color: pink; } }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("@media print{ a { color: pink; } }", _.messages.rejectedBeforeSingleLine());

  // Ignoring multi-line blocks
  tr.ok("a { color:\npink; }");
  tr.ok("a { color:\r\npink; }", "CRLF");
  tr.ok("@media print { a { color:\npink; } }");
  tr.ok("@media print{ a{ color:\npink; } }");
  tr.ok("@media print {\na{ color: pink; } }");
  tr.ok("@media print{\na{ color: pink; } }");
  tr.ok("@media print{\r\na{ color: pink; } }", "CRLF");
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink;\nbackground: orange; }");
  tr.ok("@media print {\na { color: pink;\nbackground: orange } }");
  tr.ok("@media print {\r\na { color: pink;\r\nbackground: orange } }", "CRLF");

  // Ignoring single-line blocks
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");
  tr.ok("a{ color: pink; }");
  tr.ok("a  { color: pink; }");
  tr.ok("a\t{ color: pink; }");

  tr.notOk("a{ color: pink;\nbackground: orange; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a  { color: pink;\nbackground: orange; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a\t{ color: pink;\nbackground: orange; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a\n{ color: pink;\nbackground: orange; }", _.messages.expectedBeforeMultiLine());
  tr.notOk("a\r\n{ color: pink;\r\nbackground: orange; }", _.messages.expectedBeforeMultiLine(), "CRLF");
  tr.notOk("@media print\n{\na { color: pink;\nbackground: orange; } }", _.messages.expectedBeforeMultiLine());
  tr.notOk("@media print { a\n{ color: pink;\nbackground: orange; } }", _.messages.expectedBeforeMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a{ color: pink;\nbackground: orange; }");
  tr.ok("@media print{\na{ color: pink;\nbackground: orange } }");
  tr.ok("@media print{\r\na{ color: pink;\r\nbackground: orange } }", "CRLF");

  // Ignoring single-line blocks
  tr.ok("a { color: pink; }");
  tr.ok("@media print { a { color: pink; } }");
  tr.ok("a{ color: pink; }");
  tr.ok("a  { color: pink; }");
  tr.ok("a\t{ color: pink; }");

  tr.notOk("a { color: pink;\nbackground: orange; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a  { color: pink;\nbackground: orange; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a\t{ color: pink;\nbackground: orange; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a\n{ color: pink;\nbackground: orange; }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("@media print\n{\na{ color: pink;\nbackground: orange; } }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("@media print{ a\n{ color: pink;\nbackground: orange; } }", _.messages.rejectedBeforeMultiLine());
  tr.notOk("@media print{ a\r\n{ color: pink;\r\nbackground: orange; } }", _.messages.rejectedBeforeMultiLine(), "CRLF");
});