"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "color-hex-case";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(h, v) {
    return "Expected \"" + h + "\" to be \"" + v + "\"";
  }
});

/**
 * @param {"lower"|"upper"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: "#" }, function (match) {

        var hexValue = /^#[0-9A-Za-z]+/.exec(value.substr(match.startIndex))[0];
        var hexValueLower = hexValue.toLowerCase();
        var hexValueUpper = hexValue.toUpperCase();

        if (expectation === "lower" && hexValue === hexValueLower) {
          return;
        }

        if (expectation === "upper" && hexValue === hexValueUpper) {
          return;
        }

        var variant = expectation === "lower" ? hexValueLower : hexValueUpper;

        (0, _utils.report)({
          message: messages.expected(hexValue, variant),
          node: decl,
          result: result,
          ruleName: ruleName
        });
      });
    });
  };
};