"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "color-hex-length";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(h, v) {
    return "Expected \"" + h + "\" to be \"" + v + "\"";
  }
});

/**
 * @param {"short"|"long"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: "#" }, function (match) {

        var hexValue = /^#[0-9A-Za-z]+/.exec(value.substr(match.startIndex))[0];

        if (expectation === "long" && hexValue.length !== 4 && hexValue.length !== 5) {
          return;
        }

        if (expectation === "short" && (hexValue.length < 6 || !canShrink(hexValue))) {
          return;
        }

        var variant = expectation === "long" ? longer : shorter;

        (0, _utils.report)({
          message: messages.expected(hexValue, variant(hexValue)),
          node: decl,
          result: result,
          ruleName: ruleName
        });
      });
    });
  };
};

function canShrink(hex) {
  hex = hex.toLowerCase();

  return hex[1] === hex[2] && hex[3] === hex[4] && hex[5] === hex[6] && (hex.length === 7 || hex.length === 9 && hex[7] === hex[8]);
}

function shorter(hex) {
  var hexVariant = "#";
  for (var i = 1; i < hex.length; i = i + 2) {
    hexVariant += hex[i];
  }
  return hexVariant;
}

function longer(hex) {
  var hexVariant = "#";
  for (var i = 1; i < hex.length; i++) {
    hexVariant += hex[i] + hex[i];
  }
  return hexVariant;
}