"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "comment-space-inside";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedOpening: "Expected single space after \"/*\"",
  rejectedOpening: "Unexpected whitespace after \"/*\"",
  expectedClosing: "Expected single space before \"*/\"",
  rejectedClosing: "Unexpected whitespace before \"*/\""
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachComment(function (comment) {

      var left = comment.left;
      var right = comment.right;

      if (left !== "" && expectation === "never") {
        (0, _utils.report)({
          message: messages.rejectedOpening,
          node: comment,
          result: result,
          ruleName: ruleName
        });
      }
      if (left !== " " && expectation === "always") {
        (0, _utils.report)({
          message: messages.expectedOpening,
          node: comment,
          result: result,
          ruleName: ruleName
        });
      }

      if (right !== "" && expectation === "never") {
        (0, _utils.report)({
          message: messages.rejectedClosing,
          node: comment,
          result: result,
          ruleName: ruleName
        });
      }
      if (right !== " " && expectation === "always") {
        (0, _utils.report)({
          message: messages.expectedClosing,
          node: comment,
          result: result,
          ruleName: ruleName
        });
      }
    });
  };
};