"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.declarationBangSpaceChecker = declarationBangSpaceChecker;

var _utils = require("../../utils");

var ruleName = "declaration-bang-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \"!\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \"!\"";
  }
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return declarationBangSpaceChecker(checker.after);
};

function declarationBangSpaceChecker(locationChecker) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      if (!decl.important) {
        return;
      }
      var declString = decl.toString();

      // Start from the right and only pay attention to the first
      // exclamation mark found
      for (var i = declString.length - 1; i >= 0; i--) {
        if (declString[i] !== "!") {
          continue;
        }
        check(declString, i, decl);
        break;
      }
    });

    function check(source, index, node) {
      locationChecker({ source: source, index: index, err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
}