"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "declaration-block-semicolon-newline-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected newline after \";\"";
  },
  expectedAfterMultiLine: function expectedAfterMultiLine() {
    return "Expected newline after \";\" in a multi-line rule";
  },
  rejectedAfterMultiLine: function rejectedAfterMultiLine() {
    return "Unexpected newline after \";\" in a multi-line rule";
  }
});

/**
 * @param {"always"|"always-multi-line"|"never-multi-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var check = (0, _utils.whitespaceChecker)("newline", expectation, messages);
  return function (root, result) {
    root.eachDecl(function (decl) {
      // Ignore last declaration if there's no trailing semicolon
      var parentRule = decl.parent;
      if (!parentRule.semicolon && parentRule.last === decl) {
        return;
      }

      var nextNode = decl.next();
      if (!nextNode) {
        return;
      }

      // Allow end-of-line comments one space after the semicolon
      var nodeToCheck = nextNode.type === "comment" && nextNode.before === " " ? nextNode.next() : nextNode;
      if (!nodeToCheck) {
        return;
      }

      check.afterOneOnly({
        source: nodeToCheck.toString(),
        index: -1,
        lineCheckStr: (0, _utils.cssStatementBlockString)(parentRule),
        err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: decl,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
};