"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "declaration-block-semicolon-newline-before";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected newline before \";\"";
  },
  expectedBeforeMultiLine: function expectedBeforeMultiLine() {
    return "Expected newline before \";\" in a multi-line rule";
  },
  rejectedBeforeMultiLine: function rejectedBeforeMultiLine() {
    return "Unexpected whitespace before \";\" in a multi-line rule";
  }
});

/**
 * @param {"always"|"always-multi-line"|"never-multi-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var check = (0, _utils.whitespaceChecker)("newline", expectation, messages);
  return function (root, result) {
    root.eachDecl(function (decl) {
      var parentRule = decl.parent;
      if (!parentRule.semicolon && parentRule.last === decl) {
        return;
      }

      var declString = decl.toString();

      check.before({
        source: declString,
        index: declString.length,
        lineCheckStr: (0, _utils.cssStatementBlockString)(parentRule),
        err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: decl,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
};