"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { color: pink; }");
  tr.ok("a::before { content: \";a\"; }");
  tr.ok("a { color: pink; top: 0;}", "no space between trailing semicolon and closing brace");
  tr.ok("a { color: pink; top: 0}");

  tr.notOk("a { color: pink;top: 0; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink;  top: 0; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink;\ntop: 0; }", _.messages.expectedAfter());
  tr.notOk("a { color: pink;\r\ntop: 0; }", _.messages.expectedAfter(), "CRLF");
  tr.notOk("a { color: pink;\ttop: 0; }", _.messages.expectedAfter());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a::before { content: \";a\"; }");
  tr.ok("a { color: pink; top: 0;}", "no space between trailing semicolon and closing brace");
  tr.ok("a,\nb { color: pink; top: 0; }", "multi-line rule, single-line declaration-block");
  tr.ok("a,\r\nb { color: pink; top: 0; }", "multi-line rule, single-line declaration-block and CRLF");

  // Ignore multi-line
  tr.ok("a {\n  color: pink;\n  top: 0;\n}");
  tr.ok("a {\r\n  color: pink;\r\n  top: 0;\r\n}", "CRLF");

  tr.notOk("a { color: pink;top: 0; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a,\nb { color: pink;top: 0; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a,\r\nb { color: pink;top: 0; }", _.messages.expectedAfterSingleLine(), "CRLF");
  tr.notOk("a { color: pink;  top: 0; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { color: pink;\ttop: 0; }", _.messages.expectedAfterSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a::before { content: \"; a\"; }");
  tr.ok("a { color: pink;top: 0; }", "space between trailing semicolon and closing brace");
  tr.ok("a,\nb { color: pink;top: 0; }", "multi-line rule, single-line declaration-block");

  // Ignore multi-line
  tr.ok("a {\n  color: pink; top: 0;\n}");
  tr.ok("a {\r\n  color: pink; top: 0;\r\n}", "CRLF");

  tr.notOk("a { color: pink; top: 0; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a,\nb { color: pink; top: 0; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a,\r\nb { color: pink; top: 0; }", _.messages.rejectedAfterSingleLine(), "CRLF");
  tr.notOk("a { color: pink;  top: 0; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { color: pink;\ttop: 0; }", _.messages.rejectedAfterSingleLine());
});