"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink ; }");
  tr.ok("a::before { content: \";a\" ; }");
  tr.ok("a { color: pink ; top: 0 ; }");
  tr.ok("a { color: pink ; top: 0}");

  tr.notOk("a { color: pink; }", _.messages.expectedBefore());
  tr.notOk("a { color: pink  ; }", _.messages.expectedBefore());
  tr.notOk("a { color: pink\t; }", _.messages.expectedBefore());
  tr.notOk("a { color: pink\n; }", _.messages.expectedBefore());
  tr.notOk("a { color: pink\r\n; }", _.messages.expectedBefore(), "CRLF");
  tr.notOk("a { color: pink ; top: 0; }", _.messages.expectedBefore());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a::before { content: \";a\"; }");
  tr.ok("a { color: pink; top: 0; }");

  tr.notOk("a { color: pink ; }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink  ; }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink\t; }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink\n; }", _.messages.rejectedBefore());
  tr.notOk("a { color: pink\r\n; }", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("a { color: pink; top: 0 ; }", _.messages.rejectedBefore());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink ; }");
  tr.ok("a::before { content: \";a\" ; }");
  tr.ok("a { color: pink ; top: 0 ; }");
  tr.ok("a,\nb { color: pink ; top: 0 ; }", "multi-line rule, single-line declaration-block");

  // Ignore multi-line
  tr.ok("a {\n  color: pink;\n  top: 0;\n}");
  tr.ok("a {\r\n  color: pink;\r\n  top: 0;\r\n}", "CRLF");

  tr.notOk("a { color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,\nb { color: pink; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,\r\nb { color: pink; }", _.messages.expectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { color: pink  ; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { color: pink\t; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { color: pink ; top: 0; }", _.messages.expectedBeforeSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a::before { content: \";a\"; }");
  tr.ok("a { color: pink; top: 0; }");
  tr.ok("a,\nb { color: pink; top: 0; }", "multi-line rule, single-line declaration-block");

  // Ignore multi-line
  tr.ok("a {\n  color: pink ;\n  top: 0 ;\n}");

  tr.notOk("a { color: pink ; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a,\nb { color: pink ; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a,\r\nb { color: pink ; }", _.messages.rejectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { color: pink  ; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { color: pink\t; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { color: pink; top: 0 ; }", _.messages.rejectedBeforeSingleLine());
});