"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.declarationColonSpaceChecker = declarationColonSpaceChecker;

var _utils = require("../../utils");

var ruleName = "declaration-colon-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \":\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \":\"";
  }
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return declarationColonSpaceChecker(checker.after);
};

function declarationColonSpaceChecker(locationChecker) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var declString = decl.toString();

      for (var i = 0, l = declString.length; i < l; i++) {
        if (declString[i] !== ":") {
          continue;
        }
        check(declString, i, decl);
        break;
      }
    });

    function check(source, index, node) {
      locationChecker({ source: source, index: index, err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
}