"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.functionCommaSpaceChecker = functionCommaSpaceChecker;

var _utils = require("../../utils");

var ruleName = "function-comma-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \",\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \",\"";
  }
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return functionCommaSpaceChecker(checker.after);
};

function functionCommaSpaceChecker(checkLocation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: ",", withinFunctionalNotation: true }, function (match) {
        checkComma(value, match.startIndex, decl);
      });
    });

    function checkComma(source, index, node) {
      checkLocation({ source: source, index: index, err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
}