"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "function-parentheses-space-inside";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedOpening: "Expected single space after \"(\"",
  rejectedOpening: "Unexpected whitespace after \"(\"",
  expectedClosing: "Expected single space before \")\"",
  rejectedClosing: "Unexpected whitespace before \")\""
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: "(" }, function (match) {
        checkOpening(value, match.startIndex, decl);
      });
      (0, _utils.styleSearch)({ source: value, target: ")" }, function (match) {
        checkClosing(value, match.startIndex, decl);
      });
    });

    function checkOpening(source, index, node) {
      var nextCharIsSpace = source[index + 1] === " ";
      if (expectation === "always") {
        if (!nextCharIsSpace || (0, _utils.isWhitespace)(source[index + 2])) {
          (0, _utils.report)({
            message: messages.expectedOpening,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      } else if (expectation === "never") {
        if (nextCharIsSpace) {
          (0, _utils.report)({
            message: messages.rejectedOpening,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      }
    }

    function checkClosing(source, index, node) {
      var prevCharIsSpace = source[index - 1] === " ";
      if (expectation === "always") {
        if (!prevCharIsSpace || (0, _utils.isWhitespace)(source[index - 2])) {
          (0, _utils.report)({
            message: messages.expectedClosing,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      } else if (expectation === "never") {
        if (prevCharIsSpace) {
          (0, _utils.report)({
            message: messages.rejectedClosing,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      }
    }
  };
};