"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "function-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected single space after \")\"",
  rejected: "Unexpected whitespace after \")\""
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: ")" }, function (match) {
        checkClosingParen(value, match.startIndex, decl);
      });
    });

    function checkClosingParen(source, index, node) {
      var nextChar = source[index + 1];
      if (expectation === "always") {
        // Allow for the next character to be a single empty space,
        // another closing parenthesis, a comma, or the end of the value
        if (nextChar === " " && !(0, _utils.isWhitespace)(source[index + 2])) {
          return;
        }
        if ([")", ",", undefined].indexOf(nextChar) !== -1) {
          return;
        }
        (0, _utils.report)({
          message: messages.expected,
          node: node,
          result: result,
          ruleName: ruleName
        });
      } else if (expectation === "never") {
        if ((0, _utils.isWhitespace)(nextChar)) {
          (0, _utils.report)({
            message: messages.rejected,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      }
    }
  };
};