"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("double", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // at-rules
  tr.ok("@import url(\"foo.css\");", _.messages.expected("double quotes"));
  tr.notOk("@import url('foo.css');", _.messages.expected("double quotes"));
  tr.notOk("@import url(foo.css);", _.messages.expected("double quotes"));

  tr.ok("@document url(\"http://www.w3.org/\");");
  tr.ok("@document url-prefix(\"http://www.w3.org/\");");
  tr.ok("@document domain(\"http://www.w3.org/\");");
  tr.notOk("@document url('http://www.w3.org/');", _.messages.expected("double quotes"));
  tr.notOk("@document url-prefix(http://www.w3.org/Style);", _.messages.expected("double quotes", "url-prefix"));
  tr.notOk("@document domain('mozilla.org');", _.messages.expected("double quotes", "domain"));

  tr.ok("@font-face { font-family: 'foo'; src: url(\"foo.ttf\"); }");
  tr.notOk("@font-face { font-family: 'foo'; src: url(foo.ttf); }", _.messages.expected("double quotes"));

  // rules
  tr.ok("a { background: url(\"foo.css\"); }");
  tr.notOk("a { background: url('foo.css'); }", _.messages.expected("double quotes"));
  tr.ok("a { cursor: url(\"foo.png\"); }");
  tr.notOk("a { cursor: url(foo.png); }", _.messages.expected("double quotes"));
  tr.ok("a { background-image: url(\"foo.css\"), url(\"bar.css\"), url(\"baz.css\"); }");
  tr.notOk("a { background-image: url(foo.css), url(\"bar.css\"), url(\"baz.css\"); }", _.messages.expected("double quotes"));
  tr.notOk("a { background-image: url(\"foo.css\"), url(bar.css), url(\"baz.css\"); }", _.messages.expected("double quotes"));
  tr.notOk("a { background-image: url(\"foo.css\"), url(\"bar.css\"), url(baz.css); }", _.messages.expected("double quotes"));
});

testRule("single", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // at-rules
  tr.ok("@import url('foo.css');", _.messages.expected("single quotes"));
  tr.notOk("@import url(\"foo.css\");", _.messages.expected("single quotes"));
  tr.notOk("@import url(foo.css);", _.messages.expected("single quotes"));

  tr.ok("@document url('http://www.w3.org/');");
  tr.ok("@document url-prefix('http://www.w3.org/');");
  tr.ok("@document domain('http://www.w3.org/');");
  tr.notOk("@document url(\"http://www.w3.org/\");", _.messages.expected("single quotes"));
  tr.notOk("@document url-prefix(http://www.w3.org/Style);", _.messages.expected("single quotes", "url-prefix"));
  tr.notOk("@document domain(\"mozilla.org\");", _.messages.expected("single quotes", "domain"));

  tr.ok("@font-face { font-family: 'foo'; src: url('foo.ttf'); }");
  tr.notOk("@font-face { font-family: 'foo'; src: url(foo.ttf); }", _.messages.expected("single quotes"));

  // rules
  tr.ok("a { background: url('foo.css'); }");
  tr.notOk("a { background: url(\"foo.css\"); }", _.messages.expected("single quotes"));
  tr.ok("a { cursor: url('foo.png'); }");
  tr.notOk("a { cursor: url(foo.png); }", _.messages.expected("single quotes"));
  tr.ok("a { background-image: url('foo.css'), url('bar.css'), url('baz.css'); }");
  tr.notOk("a { background-image: url(foo.css), url('bar.css'), url('baz.css'); }", _.messages.expected("single quotes"));
  tr.notOk("a { background-image: url('foo.css'), url(bar.css), url('baz.css'); }", _.messages.expected("single quotes"));
  tr.notOk("a { background-image: url('foo.css'), url('bar.css'), url(baz.css); }", _.messages.expected("single quotes"));
});

testRule("none", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  // at-rules
  tr.ok("@import url(foo.css);", _.messages.expected("no quotes"));
  tr.notOk("@import url(\"foo.css\");", _.messages.expected("no quotes"));
  tr.notOk("@import url('foo.css');", _.messages.expected("no quotes"));

  tr.ok("@document url(http://www.w3.org/);");
  tr.ok("@document url-prefix(http://www.w3.org/);");
  tr.ok("@document domain(http://www.w3.org/);");
  tr.notOk("@document url(\"http://www.w3.org/\");", _.messages.expected("no quotes"));
  tr.notOk("@document url-prefix('http://www.w3.org/Style');", _.messages.expected("no quotes", "url-prefix"));
  tr.notOk("@document domain(\"mozilla.org\");", _.messages.expected("no quotes", "domain"));

  tr.ok("@font-face { font-family: foo; src: url(foo.ttf); }");
  tr.notOk("@font-face { font-family: foo; src: url('foo.ttf'); }", _.messages.expected("no quotes"));

  // rules
  tr.ok("a { background: url(foo.css); }");
  tr.notOk("a { background: url(\"foo.css\"); }", _.messages.expected("no quotes"));
  tr.ok("a { cursor: url(foo.png); }");
  tr.notOk("a { cursor: url(\"foo.png\"); }", _.messages.expected("no quotes"));
  tr.ok("a { background-image: url(foo.css), url(bar.css), url(baz.css); }");
  tr.notOk("a { background-image: url('foo.css'), url(bar.css), url(baz.css); }", _.messages.expected("no quotes"));
  tr.notOk("a { background-image: url(foo.css), url('bar.css'), url(baz.css); }", _.messages.expected("no quotes"));
  tr.notOk("a { background-image: url(foo.css), url(bar.css), url('baz.css'); }", _.messages.expected("no quotes"));
});