"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "function-url-quotes";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(q) {
    var f = arguments.length <= 1 || arguments[1] === undefined ? "url" : arguments[1];
    return "Expected " + q + " around " + f + " argument";
  }
});

/**
 * @param {"single"|"double"|"none"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {

  var quoteMsg = (function () {
    switch (expectation) {
      case "single":
        return "single quotes";
      case "double":
        return "double quotes";
      case "none":
        return "no quotes";
    }
  })();

  var charDefiesExpectation = (function () {
    switch (expectation) {
      case "single":
        return function (c) {
          return c !== "'";
        };
      case "double":
        return function (c) {
          return c !== "\"";
        };
      case "none":
        return function (c) {
          return c === "'" || c === "\"";
        };
    }
  })();

  function strDefiesExpectation(str) {
    return charDefiesExpectation(str[0]) || charDefiesExpectation(str[str.length - 1]);
  }

  return function (root, result) {
    root.eachAtRule(check);
    root.eachRule(check);

    function check(statement) {
      if (statement.type === "atrule") {
        checkAtRuleParams(statement);
      }

      statement.eachDecl(function (decl) {
        (0, _utils.cssFunctionArguments)(decl.value, "url", function (args) {
          if (strDefiesExpectation(args)) {
            (0, _utils.report)({
              message: messages.expected(quoteMsg),
              node: decl,
              result: result,
              ruleName: ruleName
            });
          }
        });
      });
    }

    function checkAtRuleParams(atRule) {
      (0, _utils.cssFunctionArguments)(atRule.params, "url", function (args) {
        if (strDefiesExpectation(args)) {
          (0, _utils.report)({
            message: messages.expected(quoteMsg),
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
      });
      (0, _utils.cssFunctionArguments)(atRule.params, "url-prefix", function (args) {
        if (strDefiesExpectation(args)) {
          (0, _utils.report)({
            message: messages.expected(quoteMsg, "url-prefix"),
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
      });
      (0, _utils.cssFunctionArguments)(atRule.params, "domain", function (args) {
        if (strDefiesExpectation(args)) {
          (0, _utils.report)({
            message: messages.expected(quoteMsg, "domain"),
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
};