/* eslint-disable indent, no-multiple-empty-lines */

"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

// 2 spaces
testRule(2, function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("/* anything\n    goes\n\t\t\twithin a comment */\n");

  // No enforcement if no newline
  tr.ok("a { top: 0; } b { top: 1px; }");
  tr.ok("a {\n  top: 0;\n}\nb { top: 1px; bottom: 4px; }");
  tr.ok("a {\n  top: 0;\n} b { top: 1px; }");

  // Real checks ...

  tr.ok("a {\n  color: pink;\n}");

  tr.ok("a { color: pink;\n}");

  tr.ok("a {\n  color: pink;\n} b { top: 0; }");

  tr.ok("a { color: pink;\n  top: 0; background: orange;\n}");

  tr.ok("a {\n  color: pink;\n}\n\n\nb {\n  color: orange\n}");

  tr.ok("a {\n  color: pink;}");

  tr.ok("a {\n  background-position: top left,\n    top right,\n    bottom left;\n  color: pink;\n}");

  // Rule start/end errors
  tr.notOk("\ta {\n  color: pink;\n}", _.messages.expected("0 spaces at line 1"));

  tr.notOk("a {\n  color: pink;\n  }", _.messages.expected("0 spaces at line 3"));

  tr.notOk("a,\nb {\n  color: pink;\n  }", _.messages.expected("0 spaces at line 4"));

  tr.notOk("a { color: pink;\n  }", _.messages.expected("0 spaces at line 2"));

  tr.notOk("a {\n  color: pink\n}\n b {\n  color: orange\n}", _.messages.expected("0 spaces at line 4"));

  tr.notOk("a {\n  color: pink\n}\nb {\n  color: orange\n }", _.messages.expected("0 spaces at line 6"));

  // Declaration errors
  tr.notOk("a {\ncolor: pink;\n}", _.messages.expected("2 spaces at line 2"));

  tr.notOk("a {\n\tcolor: pink;\n}", _.messages.expected("2 spaces at line 2"));

  tr.notOk("a {\n  color: pink;\n background: orange;\n}", _.messages.expected("2 spaces at line 3"));

  tr.notOk("a {\n  background-position: top left,\n  top right,\n    bottom left;\n  color: pink;\n}", _.messages.expected("4 spaces at line 3"));

  tr.notOk("a {\n  background-position: top left,\n    top right,\n  bottom left;\n  color: pink;\n}", _.messages.expected("4 spaces at line 4"));
});

// tab
testRule("tab", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("");
  tr.ok("a {color: pink;}");

  tr.ok("a {\n\tcolor: pink;\n}");

  tr.ok("a {\n\tcolor: pink;\n}\n\nb {\n\tcolor: orange\n}");

  tr.ok("a {\n\tcolor: pink;}");

  // Rule start/end errors
  tr.notOk("\ta {\n\tcolor: pink;\n}", _.messages.expected("0 tabs at line 1"));

  tr.notOk("a {\n\tcolor: pink;\n  }", _.messages.expected("0 tabs at line 3"));

  tr.notOk("a {\n\tcolor: pink\n}\n b {\n\tcolor: orange\n}", _.messages.expected("0 tabs at line 4"));

  tr.notOk("a {\n\tcolor: pink\n}\nb {\n\tcolor: orange\n }", _.messages.expected("0 tabs at line 6"));

  // Declaration errors
  tr.notOk("a {\ncolor: pink;\n}", _.messages.expected("1 tab at line 2"));

  tr.notOk("a {\n  color: pink;\n}", _.messages.expected("1 tab at line 2"));

  tr.notOk("a {\n\tcolor: pink;\n background: orange;\n}", _.messages.expected("1 tab at line 3"));

  tr.notOk("a { color: pink;\ntop: 0; background: orange;\n}", _.messages.expected("1 tab at line 2"));
});

// 2 spaces except value
testRule(2, { except: ["value"] }, function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {\n  background-position: top left, top right, bottom left;\n  color: pink;\n}");

  tr.ok("a {\n  background-position: top left,\n  top right,\n  bottom left;\n  color: pink;\n}");

  tr.notOk("a {\n  background-position: top left,\n    top right,\n  bottom left;\n  color: pink;\n}", _.messages.expected("2 spaces at line 3"));

  tr.notOk("a {\n  background-position: top left,\n  top right,\n    bottom left;\n  color: pink;\n}", _.messages.expected("2 spaces at line 4"));
});