"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findMediaOperator = findMediaOperator;

var _utils = require("../../utils");

var ruleName = "media-feature-range-operator-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after range operator";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after range operator";
  }
});

exports.messages = messages;
var rangeOperatorRegex = /[^><](>=?|<=?|=)/g;

/**
 * @param {"always"|"never"} expectation
 */

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    root.eachAtRule(function (atRule) {
      findMediaOperator(atRule, checkAfterOperator);
    });

    function checkAfterOperator(match, params, node) {
      checker.after({
        source: params,
        index: match.index + match[1].length,
        err: function err(m) {
          (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
};

function findMediaOperator(atRule, cb) {
  if (atRule.name !== "media") {
    return;
  }

  var params = atRule.params;
  var match = undefined;
  while ((match = rangeOperatorRegex.exec(params)) !== null) {
    cb(match, params, atRule);
  }
}