"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var _mediaFeatureRangeOperatorSpaceAfter = require("../media-feature-range-operator-space-after");

var ruleName = "media-feature-range-operator-space-before";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected single space before range operator";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected whitespace before range operator";
  }
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    root.eachAtRule(function (atRule) {
      (0, _mediaFeatureRangeOperatorSpaceAfter.findMediaOperator)(atRule, checkBeforeOperator);
    });

    function checkBeforeOperator(match, params, node) {
      // The extra `+ 1` is because the match itself contains
      // the character before the operator
      checker.before({
        source: params,
        index: match.index + 1,
        err: function err(m) {
          (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
};