"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@media (max-width: 600px) {}");
  tr.ok("@media screen and (color) , projection and (color) {}");
  tr.ok("@media screen and (color) ,  projection and (color) {}");
  tr.ok("@media screen and (color) ,\nprojection and (color) {}");
  tr.ok("@media screen and (color) ,\r\nprojection and (color) {}", "CRLF");

  tr.notOk("@media screen and (color), projection and (color)", _.messages.expectedBefore());
  tr.notOk("@media screen and (color)  , projection and (color)", _.messages.expectedBefore());
  tr.notOk("@media screen and (color)\n, projection and (color)", _.messages.expectedBefore());
  tr.notOk("@media screen and (color)\r\n, projection and (color)", _.messages.expectedBefore(), "CRLF");
  tr.notOk("@media screen and (color)\t, projection and (color)", _.messages.expectedBefore());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@media (max-width: 600px) {}");
  tr.ok("@media screen and (color),projection and (color) {}");
  tr.ok("@media screen and (color), projection and (color) {}");
  tr.ok("@media screen and (color),\nprojection and (color) {}");
  tr.ok("@media screen and (color),\r\nprojection and (color) {}", "CRLF");

  tr.notOk("@media screen and (color) , projection and (color)", _.messages.rejectedBefore());
  tr.notOk("@media screen and (color)  , projection and (color)", _.messages.rejectedBefore());
  tr.notOk("@media screen and (color)\n, projection and (color)", _.messages.rejectedBefore());
  tr.notOk("@media screen and (color)\r\n, projection and (color)", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("@media screen and (color)\t, projection and (color)", _.messages.rejectedBefore());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@media screen and (color) ,projection and (color) {}");
  tr.ok("@media screen and (color) ,projection and (color) {\n}", "single-line list, multi-line block");
  tr.ok("@media screen and (color) ,projection and (color) {\r\n}", "single-line list, multi-line block and CRLF");
  tr.ok("@media screen and (color),\nprojection and (color) {}", "ignore multi-line");
  tr.ok("@media screen and (color),\r\nprojection and (color) {}", "ignore multi-line", "CRLF");

  tr.notOk("@media screen and (color), projection and (color) {}", _.messages.expectedBeforeSingleLine());
  tr.notOk("@media screen and (color), projection and (color) {\n}", _.messages.expectedBeforeSingleLine(), "single-line list, multi-line block");
  tr.notOk("@media screen and (color), projection and (color) {\r\n}", _.messages.expectedBeforeSingleLine(), "single-line list, multi-line block and CRLF");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("@media screen and (color), projection and (color) {}");
  tr.ok("@media screen and (color), projection and (color) {\n}", "single-line list, multi-line block");
  tr.ok("@media screen and (color), projection and (color) {\r\n}", "single-line list, multi-line block and CRLF");
  tr.ok("@media screen and (color)\n,projection and (color) {}", "ignore multi-line");
  tr.ok("@media screen and (color)\r\n,projection and (color) {}", "ignore multi-line and CRLF");

  tr.notOk("@media screen and (color) ,projection and (color) {}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("@media screen and (color) ,projection and (color) {\n}", _.messages.rejectedBeforeSingleLine(), "single-line list, multi-line block");
  tr.notOk("@media screen and (color) ,projection and (color) {\r\n}", _.messages.rejectedBeforeSingleLine(), "single-line list, multi-line block and CRLF");
});