"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "media-query-parentheses-space-inside";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedOpening: "Expected single space after \"(\"",
  rejectedOpening: "Unexpected whitespace after \"(\"",
  expectedClosing: "Expected single space before \")\"",
  rejectedClosing: "Unexpected whitespace before \")\""
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachAtRule(function (atRule) {
      if (atRule.name !== "media") {
        return;
      }

      var params = atRule.params;

      (0, _utils.styleSearch)({ source: params, target: "(" }, function (match) {
        var nextCharIsSpace = params[match.startIndex + 1] === " ";
        if (nextCharIsSpace && expectation === "never") {
          (0, _utils.report)({
            message: messages.rejectedOpening,
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
        if (!nextCharIsSpace && expectation === "always") {
          (0, _utils.report)({
            message: messages.expectedOpening,
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
      });

      (0, _utils.styleSearch)({ source: params, target: ")" }, function (match) {
        var prevCharIsSpace = params[match.startIndex - 1] === " ";
        if (prevCharIsSpace && expectation === "never") {
          (0, _utils.report)({
            message: messages.rejectedClosing,
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
        if (!prevCharIsSpace && expectation === "always") {
          (0, _utils.report)({
            message: messages.expectedClosing,
            node: atRule,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
};