"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkNestingBlockOpeningBraceBefore = checkNestingBlockOpeningBraceBefore;

var _utils = require("../../utils");

var ruleName = "nesting-block-opening-brace-newline-before";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected newline before \"{\"";
  },
  expectedBeforeSingleLine: function expectedBeforeSingleLine() {
    return "Expected newline before \"{\" of a single-line nesting block";
  },
  rejectedBeforeSingleLine: function rejectedBeforeSingleLine() {
    return "Unexpected whitespace before \"{\" of a single-line nesting block";
  },
  expectedBeforeMultiLine: function expectedBeforeMultiLine() {
    return "Expected newline before \"{\" of a multi-line nesting block";
  },
  rejectedBeforeMultiLine: function rejectedBeforeMultiLine() {
    return "Unexpected whitespace before \"{\" of a multi-line nesting block";
  }
});

/**
 * @param {"always"|"always-single-line"|"never-single-line"|"always-multi-line"|"never-multi-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("newline", expectation, messages);
  return checkNestingBlockOpeningBraceBefore(checker);
};

function checkNestingBlockOpeningBraceBefore(checker) {
  return function (root, result) {
    root.eachRule(function (rule) {
      if (!(0, _utils.cssStatementIsNestingBlock)(rule) || (0, _utils.cssStatementHasEmptyBlock)(rule)) {
        return;
      }

      // console.log(JSON.stringify(rule.toString()))

      var beforeBrace = (0, _utils.cssStatementStringBeforeBlock)(rule);
      var lineCheckStr = rule.toString().slice(beforeBrace.length);
      checker.beforeAllowingIndentation({
        lineCheckStr: lineCheckStr,
        source: beforeBrace,
        index: beforeBrace.length,
        err: function err(m) {
          (0, _utils.report)({
            message: m,
            node: rule,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
}