"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { { &:hover { color: pink; }}}");
  tr.ok("a { { &:hover { &:before { color: pink; }}}}");

  tr.notOk("a {{ &:hover { color: pink; }}}", _.messages.expectedBefore());
  tr.notOk("a {{ &:hover {\ncolor: pink; }}}", _.messages.expectedBefore());
  tr.notOk("a {\t{ &:hover { color: pink; }}}", _.messages.expectedBefore());
  tr.notOk("a { { &:hover {\n{ &:before { color: pink; }}}}}", _.messages.expectedBefore());
  tr.notOk("a {\n{ &:hover { { &:before { color: pink; }}}}}", _.messages.expectedBefore());
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a {{ &:hover { color: pink; }}}");
  tr.ok("a {{ &:hover { &:before { color: pink; }}}}");

  tr.notOk("a { { &:hover { color: pink; }}}", _.messages.rejectedBefore());
  tr.notOk("a {  { &:hover {\ncolor: pink; }}}", _.messages.rejectedBefore());
  tr.notOk("a {\t{ &:hover { color: pink; }}}", _.messages.rejectedBefore());
  tr.notOk("a {\r\n{ &:hover {{ &:before { color: pink; }}}}}", _.messages.rejectedBefore());
  tr.notOk("a {{ &:hover {\n{ &:before { color: pink; }}}}}", _.messages.rejectedBefore());
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { color: pink; }");
  tr.ok("a { { &:hover { color: pink; }}}");
  tr.ok("a { { &:hover { color: pink; }}}", "CRLF");
  tr.ok("a { { &:hover { &:before { color: pink; }}}}");

  tr.ok("a {{ &:hover\n{ color: pink;\n}}}", "multi-line");
  tr.ok("a {{ &:hover \n{ { &:before { color: pink; }}}}}", "multi-line");

  tr.notOk("a {{ &:hover { color: pink; }}}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a {\t{ &:hover { color: pink; }}}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a {\n{ &:hover { { &:before { color: pink; }}}}}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { { &:hover {\n{ &:before { color: pink; }}}}}", _.messages.expectedBeforeSingleLine());
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {{ &:hover { color: pink; }}}");
  tr.ok("a {{ &:hover { color: pink; }}}", "CRLF");
  tr.ok("a {{ &:hover {{ &:before { color: pink; }}}}}");

  tr.ok("a { { &:hover\n{ color: pink; }}}", "multi-line");

  tr.notOk("a { { &:hover { color: pink; }}}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a {\n{ &:hover { color: pink; }}}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a {\r\n{ &:hover { color: pink; }}}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a {\n\t{ &:hover {{ &:before { color: pink; }}}}}", _.messages.rejectedBeforeSingleLine());
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {\ncolor: pink; }");
  tr.ok("a { { &:hover\n{ color: pink; }}}");
  tr.ok("a { { &:hover\r\n{ color: pink; }}}", "CRLF");
  tr.ok("a { { &:hover { &:before\n{ color: pink; }}}}");

  tr.ok("a {{ &:hover { color: pink; }}}", "single-line");
  tr.ok("a {{ &:hover {\t\t\t{ &:before { color: pink; }}}}}", "single-line");

  tr.notOk("a {{ &:hover\n{ color: pink; }}}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a {\t{ &:hover\n{ color: pink; }}}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a { { &:hover {{ &:before\r\n{ color: pink; }}}}}", _.messages.expectedBeforeMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a {{ &:hover\n{ color: pink; }}}");
  tr.ok("a {{ &:hover\n{ color: pink; }}}", "CRLF");
  tr.ok("a {{ &:hover\n{{ &:before\n{ color: pink; }}}}}");

  tr.ok("a { { &:hover { color: pink; }}}", "single-line");
  tr.ok("a {\t\t{ &:hover { color: pink; }}}", "single-line");

  tr.notOk("a { { &:hover\n{ color: pink; }}}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a {\t{ &:hover\r\n{ color: pink; }}}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a { { &:hover {{ &:before\n{ color: pink; }}}}}", _.messages.rejectedBeforeMultiLine());
});