"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "number-leading-zero";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected a leading zero",
  rejected: "Unexpected leading zero"
});

/**
 * @param {"always"|"never"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachDecl(function (decl) {
      check(decl.value, decl);
    });

    root.eachAtRule(function (atRule) {
      check(atRule.params, atRule);
    });

    function check(source, node) {
      // Get out quickly if there are no periods
      if (source.indexOf(".") === -1) {
        return;
      }

      // check leadingzero
      if (expectation === "always" && !lacksLeadingZero(source)) {
        return;
      }
      if (expectation === "never" && !containsLeadingZero(source)) {
        return;
      }

      var message = expectation === "always" ? messages.expected : messages.rejected;

      (0, _utils.report)({
        message: message,
        node: node,
        result: result,
        ruleName: ruleName
      });
    }
  };
};

function lacksLeadingZero(value) {
  return /(?:\D|^)\.\d+/g.test(value);
}

function containsLeadingZero(value) {
  return /(?:\D|^)0\.\d+/g.test(value);
}