"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "number-no-trailing-zeros";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  rejected: "Unexpected trailing zero(s)"
});

exports.messages = messages;

exports["default"] = function () {
  return function (root, result) {
    root.eachDecl(function (decl) {
      check(decl.value, decl);
    });

    root.eachAtRule(function (atRule) {
      check(atRule.params, atRule);
    });

    function check(source, node) {
      // Get out quickly if there are no periods
      if (source.indexOf(".") === -1) {
        return;
      }

      if (/\.\d*0+(?:\D|$)/g.test(source)) {
        (0, _utils.report)({
          message: messages.rejected,
          node: node,
          result: result,
          ruleName: ruleName
        });
      }
    }
  };
};