"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkRuleEmptyLineBefore = checkRuleEmptyLineBefore;

var _utils = require("../../utils");

var ruleName = "rule-non-nested-empty-line-before";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected empty line before non-nested rule",
  rejected: "Unexpected empty line before non-nested rule"
});

/**
 * @param {"always"|"never"|"always-multi-line"|"never-multi-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation, options) {
  return function (root, result) {
    root.eachRule(function (rule) {

      // Ignore nested rule sets
      if (rule.parent !== root) {
        return;
      }

      // Ignore the first node
      if (rule === root.first) {
        return;
      }

      checkRuleEmptyLineBefore(rule, expectation, options, result, messages);
    });
  };
};

function checkRuleEmptyLineBefore(rule, expectation, options, result, msgs) {

  var expectEmptyLineBefore = expectation.indexOf("always") !== -1 ? true : false;

  // Optionally ignore the expectation if a comment precedes this node
  if ((0, _utils.optionsHaveIgnored)(options, "after-comment") && rule.prev() && rule.prev().type === "comment") {
    return;
  }

  // Ignore if the exceptation is for multiple and the rule is single-line
  if (expectation.indexOf("multi-line") !== -1 && (0, _utils.isSingleLineString)(rule.toString())) {
    return;
  }

  // Optionally reverse the expectation for the first nested node
  if ((0, _utils.optionsHaveException)(options, "first-nested") && rule === rule.parent.first) {
    expectEmptyLineBefore = !expectEmptyLineBefore;
  }

  var emptyLineBefore = rule.before.indexOf("\n\n") !== -1 || rule.before.indexOf("\r\n\r\n") !== -1;

  // Return if the exceptation is met
  if (expectEmptyLineBefore === emptyLineBefore) {
    return;
  }

  var message = expectEmptyLineBefore ? msgs.expected : msgs.rejected;

  (0, _utils.report)({
    message: message,
    node: rule,
    result: result,
    ruleName: ruleName
  });
}