"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a + a {}", "space before and after + combinator");
  tr.ok("a > a {}", "space before and after > combinator");
  tr.ok("a ~ a {}", "space before and after ~ combinator");
  tr.ok(".foo ~ a + bar {}", "multiple spaced combinators");
  tr.ok("a+ a {}", "no before and one after + combinator");
  tr.ok("a> a {}", "no before and one after > combinator");
  tr.ok("a~ a {}", "no before and one after ~ combinator");
  tr.ok("a\n+ a {}", "newline before space after + combinator");
  tr.ok("a\n> a {}", "newline before space after > combinator");
  tr.ok("a\r\n> a {}", "CRLF before space after > combinator");
  tr.ok("a\n~ a {}", "newline before space after ~ combinator");
  tr.ok(".foo~ a+ bar {}", "multiple combinators with no space before and one after");
  tr.ok(".foo:nth-child(2n+1) {}", "unspaced + in nth-child argument");
  tr.ok(".foo:nth-child(2n-1) {}", "unspaced - in nth-child argument");
  tr.ok("a[rel~='copyright'] {}", "attribute selector with ~=");

  tr.notOk("a+  a {}", _.messages.expectedAfter("+"), "two spaces after + combinator");
  tr.notOk("a+\na {}", _.messages.expectedAfter("+"), "newline after + combinator");
  tr.notOk("a+a {}", _.messages.expectedAfter("+"), "no space after + combinator");
  tr.notOk("a>a {}", _.messages.expectedAfter(">"), "no space after > combinator");
  tr.notOk("a~a {}", _.messages.expectedAfter("~"), "no space after ~ combinator");
  tr.notOk("a + .foo.bar ~a {}", _.messages.expectedAfter("~"), "multiple combinators: no space after ~ combinator");
  tr.notOk("#foo +.foo.bar ~ a {}", _.messages.expectedAfter("+"), "multiple combinators: no space after + combinator");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a +a {}", "space before none after + combinator");
  tr.ok("a >a {}", "space before none after > combinator");
  tr.ok("a ~a {}", "space before none after ~ combinator");
  tr.ok(".foo ~a +bar {}", "multiple combinators with no space after");
  tr.ok("a+a {}", "no space before or after + combinator");
  tr.ok("a>a {}", "no space before or after > combinator");
  tr.ok("a~a {}", "no space before or after ~ combinator");
  tr.ok("a\n+a {}", "newline before and no space after + combinator");
  tr.ok("a\r\n+a {}", "CRLF before and no space after + combinator");
  tr.ok("a\n>a {}", "newline before and no space after > combinator");
  tr.ok("a\n~a {}", "newline before and no space after ~ combinator");
  tr.ok("a\r\n~a {}", "CRLF before and no space after ~ combinator");
  tr.ok(".foo:nth-child(2n + 1) {}", "spaced + in nth-child argument");
  tr.ok(".foo:nth-child(2n - 1) {}", "spaced - in nth-child argument");
  tr.ok("a[rel~='copyright'] {}", "attribute selector with ~=");

  tr.notOk("a+ a {}", _.messages.rejectedAfter("+"), "space after + combinator");
  tr.notOk("a> a {}", _.messages.rejectedAfter(">"), "space after > combinator");
  tr.notOk("a~ a {}", _.messages.rejectedAfter("~"), "space after ~ combinator");
  tr.notOk("a+\na{}", _.messages.rejectedAfter("+"), "newline after + combinator");
  tr.notOk("a+\r\na{}", _.messages.rejectedAfter("+"), "CRLF after + combinator");
  tr.notOk("a>\na{}", _.messages.rejectedAfter(">"), "newline after > combinator");
  tr.notOk("a~\na{}", _.messages.rejectedAfter("~"), "newline after ~ combinator");
  tr.notOk("a~\r\na{}", _.messages.rejectedAfter("~"), "CRLF after ~ combinator");
  tr.notOk("a + .foo.bar ~a {}", _.messages.rejectedAfter("+"), "multiple combinators: space after + combinator");
  tr.notOk("#foo +.foo.bar ~ a {}", _.messages.rejectedAfter("~"), "multiple combinators: no space after ~ combinator");
});