"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.selectorCombinatorSpaceChecker = selectorCombinatorSpaceChecker;

var _utils = require("../../utils");

var ruleName = "selector-combinator-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter(c) {
    return "Expected single space after \"" + c + "\" combinator ";
  },
  rejectedAfter: function rejectedAfter(c) {
    return "Unexpected whitespace after \"" + c + "\" combinator";
  }
});

exports.messages = messages;
var combinators = [">", "+", "~"];

/**
 * @param {"always"|"never"} expectation
 */

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return selectorCombinatorSpaceChecker(checker.after);
};

function selectorCombinatorSpaceChecker(locationChecker) {
  return function (root, result) {
    root.eachRule(function (rule) {
      var selector = rule.selector;
      (0, _utils.styleSearch)({
        source: selector,
        target: combinators,
        outsideFunctionalNotation: true
      }, function (match) {
        // Catch ~= in attribute selectors
        if (match.target === "~" && selector[match.endIndex] === "=") {
          return;
        }

        check(selector, match.startIndex, rule);
      });
    });

    function check(source, index, node) {
      locationChecker({ source: source, index: index, err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
}