"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a + a {}", "space before and after + combinator");
  tr.ok("a > a {}", "space before and after > combinator");
  tr.ok("a ~ a {}", "space before and after ~ combinator");
  tr.ok(".foo ~ a + bar {}", "multiple spaced combinators");
  tr.ok("a +a {}", "space before and none after + combinator");
  tr.ok("a >a {}", "space before and none after > combinator");
  tr.ok("a ~a {}", "space before and none after ~ combinator");
  tr.ok("a +\na {}", "space before and newline after + combinator");
  tr.ok("a +\r\na {}", "space before and CRLF after + combinator");
  tr.ok("a >\na {}", "space before and newline after > combinator");
  tr.ok("a ~\na {}", "space before and newline after ~ combinator");
  tr.ok("a ~\r\na {}", "space before and CRLF after ~ combinator");
  tr.ok(".foo ~a +bar {}", "multiple combinators with space before and none after");
  tr.ok(".foo:nth-child(2n+1) {}", "unspaced + in nth-child argument");
  tr.ok(".foo:nth-child(2n-1) {}", "unspaced - in nth-child argument");
  tr.ok("a[rel~='copyright'] {}", "attribute selector with ~=");

  tr.notOk("a  +a {}", _.messages.expectedBefore("+"), "two spaces before + combinator");
  tr.notOk("a\n+ a {}", _.messages.expectedBefore("+"), "newline before + combinator");
  tr.notOk("a\r\n+ a {}", _.messages.expectedBefore("+"), "CRLF before + combinator");
  tr.notOk("a+a {}", _.messages.expectedBefore("+"), "no space before + combinator");
  tr.notOk("a>a {}", _.messages.expectedBefore(">"), "no space before > combinator");
  tr.notOk("a~a {}", _.messages.expectedBefore("~"), "no space before ~ combinator");
  tr.notOk("a + .foo.bar~ a {}", _.messages.expectedBefore("~"), "multiple combinators: no space before ~ combinator");
  tr.notOk("#foo+ .foo.bar ~ a {}", _.messages.expectedBefore("+"), "multiple combinators: no space before + combinator");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a+ a {}", "no space before one after + combinator");
  tr.ok("a> a {}", "no space before one after > combinator");
  tr.ok("a~ a {}", "no space before one after ~ combinator");
  tr.ok("a+a {}", "no space before or after + combinator");
  tr.ok("a>a {}", "no space before or after > combinator");
  tr.ok("a~a {}", "no space before or after ~ combinator");
  tr.ok("a+\na {}", "no space before and newline after + combinator");
  tr.ok("a>\na {}", "no space before and newline after > combinator");
  tr.ok("a>\r\na {}", "no space before and CRLF after > combinator");
  tr.ok("a~\na {}", "no space before and newline after ~ combinator");
  tr.ok(".foo~ a+ bar {}", "multiple combinators with no space before");
  tr.ok(".foo:nth-child(2n + 1) {}", "spaced + in nth-child argument");
  tr.ok(".foo:nth-child(2n - 1) {}", "spaced - in nth-child argument");
  tr.ok("a[rel~='copyright'] {}", "attribute selector with ~=");

  tr.notOk("a +a {}", _.messages.rejectedBefore("+"), "space before + combinator");
  tr.notOk("a >a {}", _.messages.rejectedBefore(">"), "space before > combinator");
  tr.notOk("a ~a {}", _.messages.rejectedBefore("~"), "space before ~ combinator");
  tr.notOk("a\n+a {}", _.messages.rejectedBefore("+"), "newline before + combinator");
  tr.notOk("a\n>a {}", _.messages.rejectedBefore(">"), "newline before > combinator");
  tr.notOk("a\n~a {}", _.messages.rejectedBefore("~"), "newline before ~ combinator");
  tr.notOk("a\r\n~a {}", _.messages.rejectedBefore("~"), "CRLF before ~ combinator");
  tr.notOk("a + .foo.bar~ a {}", _.messages.rejectedBefore("+"), "multiple combinators: space before + combinator");
  tr.notOk("#foo+ .foo.bar ~ a {}", _.messages.rejectedBefore("~"), "multiple combinators: no space before ~ combinator");
});