"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a\n,b {}");
  tr.ok("a\n,b\n,c {}");
  tr.ok("a\r\n,b\r\n,c {}", "CRLF");
  tr.ok("a\n, b {}");
  tr.ok("a\n,\nb {}");
  tr.ok("a\r\n,\r\nb {}", "CRLF");
  tr.ok("a\n,b[data-foo=\"tr,tr\"] {}");
  tr.ok("a\n    ,b {}", "indentation after the newline before the comma");
  tr.ok("a\r\n    ,b {}", "indentation after the CRLF before the comma");
  tr.ok("a\n\t\t,b {}", "indentation after the newline before the comma");
  tr.ok("\ta\n\t, b {}", "indented statement");

  tr.notOk("a,b {}", _.messages.expectedBefore());
  tr.notOk("a ,b {}", _.messages.expectedBefore());
  tr.notOk("a  ,b {}", _.messages.expectedBefore());
  tr.notOk("a\t,b {}", _.messages.expectedBefore());
  tr.notOk("a\n,b,c {}", _.messages.expectedBefore());
  tr.notOk("a\r\n,b,c {}", _.messages.expectedBefore(), "CRLF");
});

testRule("always-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a\n,b {}");
  tr.ok("a\r\n,b {}", "CRLF");
  tr.ok("a, b {}", "ignores single-line");
  tr.ok("a, b {\n}", "ignores single-line selector list, multi-line block");
  tr.ok("\ta\n\t, b {\n}", "indented statement");

  tr.notOk("a\n,b, c {}", _.messages.expectedBeforeMultiLine());
  tr.notOk("a\r\n,b, c {}", _.messages.expectedBeforeMultiLine(), "CRLF");
  tr.notOk("a\n,b, c {\n}", _.messages.expectedBeforeMultiLine());
});

testRule("never-multi-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a,\nb {}");
  tr.ok("a ,b {}", "ignores single-line");
  tr.ok("a ,b {\n}", "ignores single-line selector list, multi-line block");
  tr.ok("a ,b {\r\n}", "ignores single-line selector list, multi-line block with CRLF");

  tr.notOk("a,\nb , c {}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a,\nb , c {\n}", _.messages.rejectedBeforeMultiLine());
  tr.notOk("a,\r\nb , c {\r\n}", _.messages.rejectedBeforeMultiLine(), "CRLF");
});