"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a, b {}");
  tr.ok("a, b, c {}");
  tr.ok("a , b {}");
  tr.ok("a\n, b {}");
  tr.ok("a\r\n, b {}", "CRLF");

  tr.notOk("a,b {}", _.messages.expectedAfter());
  tr.notOk("a,  b {}", _.messages.expectedAfter());
  tr.notOk("a,\nb {}", _.messages.expectedAfter());
  tr.notOk("a,\r\nb {}", _.messages.expectedAfter(), "CRLF");
  tr.notOk("a,\tb {}", _.messages.expectedAfter());
  tr.notOk("a, b,c {}", _.messages.expectedAfter());
  tr.notOk("a, b,  c {}", _.messages.expectedAfter());

  tr.ok("a, b[data-foo=\"tr,tr\"] {}", "string");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a,b {}");
  tr.ok("a,b,c {}");
  tr.ok("a ,b {}");
  tr.ok("a\n,b {}");
  tr.ok("a\r\n,b {}", "CRLF");

  tr.notOk("a, b {}", _.messages.rejectedAfter());
  tr.notOk("a,  b {}", _.messages.rejectedAfter());
  tr.notOk("a,\nb {}", _.messages.rejectedAfter());
  tr.notOk("a,\r\nb {}", _.messages.rejectedAfter(), "CRLF");
  tr.notOk("a,\tb {}", _.messages.rejectedAfter());
  tr.notOk("a,b, c {}", _.messages.rejectedAfter());
  tr.notOk("a,b,  c {}", _.messages.rejectedAfter());

  tr.ok("a,b[data-foo=\"tr, tr\"] {}", "string");
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a, b {}");
  tr.ok("a, b {\n}", "single-line selector list, multi-line block");
  tr.ok("a, b {\r\n}", "single-line selector list, multi-line block with CRLF");

  tr.notOk("a,b {}", _.messages.expectedAfterSingleLine());
  tr.notOk("a,b {\n}", _.messages.expectedAfterSingleLine());
  tr.notOk("a,b {\r\n}", _.messages.expectedAfterSingleLine(), "CRLF");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a,b {}");
  tr.ok("a,b {\n}", "single-line selector list, multi-line block");
  tr.ok("a,b {\r\n}", "single-line selector list, multi-line block with CRLF");

  tr.notOk("a, b {}", _.messages.rejectedAfterSingleLine());
  tr.notOk("a, b {\n}", _.messages.rejectedAfterSingleLine());
  tr.notOk("a, b {\r\n}", _.messages.rejectedAfterSingleLine(), "CRLF");
});