"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.selectorListCommaWhitespaceChecker = selectorListCommaWhitespaceChecker;

var _utils = require("../../utils");

var ruleName = "selector-list-comma-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \",\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \",\"";
  },
  expectedAfterSingleLine: function expectedAfterSingleLine() {
    return "Expected single space after \",\" in a single-line list";
  },
  rejectedAfterSingleLine: function rejectedAfterSingleLine() {
    return "Unexpected whitespace after \",\" in a single-line list";
  }
});

/**
 * @param {"always"|"never"|"always-single-line"|"never-single-line"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return selectorListCommaWhitespaceChecker(checker.after);
};

function selectorListCommaWhitespaceChecker(checkLocation) {
  return function (root, result) {
    root.eachRule(function (rule) {
      var selector = rule.selector;
      (0, _utils.styleSearch)({ source: selector, target: "," }, function (match) {
        checkDelimiter(selector, match.startIndex, rule);
      });
    });

    function checkDelimiter(source, index, node) {
      checkLocation({ source: source, index: index, err: function err(m) {
          return (0, _utils.report)({
            message: m,
            node: node,
            result: result,
            ruleName: ruleName
          });
        }
      });
    }
  };
}