"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a ,b {}");
  tr.ok("a ,b ,c {}");
  tr.ok("a , b {}");
  tr.ok("a ,\nb {}");
  tr.ok("a ,\r\nb {}", "CRLF");

  tr.notOk("a,b {}", _.messages.expectedBefore());
  tr.notOk("a  ,b {}", _.messages.expectedBefore());
  tr.notOk("a\n,b {}", _.messages.expectedBefore());
  tr.notOk("a\r\n,b {}", _.messages.expectedBefore(), "CRLF");
  tr.notOk("a\t,b {}", _.messages.expectedBefore());
  tr.notOk("a ,b,c {}", _.messages.expectedBefore());
  tr.notOk("a ,b  ,c {}", _.messages.expectedBefore());

  tr.ok("a ,b[data-foo=\"tr,tr\"] {}", "string");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a,b {}");
  tr.ok("a,b,c {}");
  tr.ok("a, b {}");
  tr.ok("a,\nb {}");
  tr.ok("a,\r\nb {}", "CRLF");

  tr.notOk("a ,b {}", _.messages.rejectedBefore());
  tr.notOk("a  ,b {}", _.messages.rejectedBefore());
  tr.notOk("a\n,b {}", _.messages.rejectedBefore());
  tr.notOk("a\r\n,b {}", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("a\t,b {}", _.messages.rejectedBefore());
  tr.notOk("a,b ,c {}", _.messages.rejectedBefore());
  tr.notOk("a,b  ,c {}", _.messages.rejectedBefore());

  tr.ok("a,b[data-foo=\"tr ,tr\"] {}", "string");
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a ,b {}");
  tr.ok("a ,b {\n}", "single-line selector list, multi-line block");
  tr.ok("a ,b {\r\n}", "single-line selector list, multi-line block with CRLF");

  tr.notOk("a,b {}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,b {\n}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a,b {\r\n}", _.messages.expectedBeforeSingleLine(), "CRLF");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a,b {}");
  tr.ok("a,b {\n}", "single-line selector list, multi-line block");
  tr.ok("a,b {\r\n}", "single-line selector list, multi-line block with CRLF");

  tr.notOk("a ,b {}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a ,b {\n}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a ,b {\r\n}", _.messages.rejectedBeforeSingleLine(), "CRLF");
});