"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "selector-psuedo-element-colon-notation";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(q) {
    return "Expected " + q + " colon pseudo-element notation";
  }
});

/**
 * @param {"single"|"double"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {

  return function (root, result) {

    root.eachRule(function (rule) {
      var selector = rule.selector;

      // get out early if no pseudo elements or classes
      if (selector.indexOf(":") === -1) {
        return;
      }

      // match only level 1 and 2 pseudo elements
      (0, _utils.styleSearch)({ source: selector, target: [":before", ":after", ":first-line", ":first-letter"] }, function (match) {

        var prevCharIsColon = selector[match.startIndex - 1] === ":";

        if (expectation === "single" && !prevCharIsColon) {
          return;
        }
        if (expectation === "double" && prevCharIsColon) {
          return;
        }

        (0, _utils.report)({
          message: messages.expected(expectation),
          node: rule,
          result: result,
          ruleName: ruleName
        });
      });
    });
  };
};