"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "string-quotes";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(q, l) {
    return "Expected " + q + " quotes around string on line " + l;
  }
});

/**
 * @param {"single"|"double"} expectation
 */
exports.messages = messages;

exports["default"] = function (expectation) {

  var erroneousQuote = expectation === "single" ? "\"" : "'";

  return function (root, result) {
    var cssString = root.source.input.css;
    (0, _utils.styleSearch)({ source: cssString, target: erroneousQuote }, function (match) {
      var line = (0, _utils.lineCount)(cssString.slice(0, match.startIndex));
      (0, _utils.report)({
        message: messages.expected(expectation, line),
        node: root,
        line: line,
        result: result,
        ruleName: ruleName
      });
    });
  };
};