"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 , 0; }");
  tr.ok("a { background-size: 0, 0; }");
  tr.notOk("a { background-size: 0,0; }", _.messages.expectedAfter());
  tr.notOk("a { background-size: 0,  0; }", _.messages.expectedAfter());
  tr.notOk("a { background-size: 0,\n0; }", _.messages.expectedAfter());
  tr.notOk("a { background-size: 0,\r\n0; }", _.messages.expectedAfter(), "CRLF");
  tr.notOk("a { background-size: 0,\t0; }", _.messages.expectedAfter());

  tr.ok("a::before { content: \"foo,bar,baz\"; }", "strings");
  tr.ok("a { transform: translate(1,1); }", "function arguments");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 ,0; }");
  tr.ok("a { background-size: 0,0; }");
  tr.notOk("a { background-size: 0, 0; }", _.messages.rejectedAfter());
  tr.notOk("a { background-size: 0,  0; }", _.messages.rejectedAfter());
  tr.notOk("a { background-size: 0,\n0; }", _.messages.rejectedAfter());
  tr.notOk("a { background-size: 0,\r\n0; }", _.messages.rejectedAfter(), "CRLF");
  tr.notOk("a { background-size: 0,\t0; }", _.messages.rejectedAfter());

  tr.ok("a::before { content: \"foo, bar, baz\"; }", "strings");
  tr.ok("a { transform: translate(1, 1); }", "function arguments");
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 , 0; }");
  tr.ok("a { background-size: 0, 0; }");
  tr.ok("a { background-size: 0, 0;\n}", "single-line list, multi-line block");
  tr.ok("a { background-size: 0, 0;\r\n}", "single-line list, multi-line block with CRLF");
  tr.ok("a { background-size: 0\n,0}", "ignores multi-line");
  tr.ok("a { background-size: 0\r\n,0}", "ignores multi-line with CRLF");

  tr.notOk("a { background-size: 0,0; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { background-size: 0,0;\n}", _.messages.expectedAfterSingleLine());
  tr.notOk("a { background-size: 0,0;\r\n}", _.messages.expectedAfterSingleLine(), "CRLF");
  tr.notOk("a { background-size: 0,  0; }", _.messages.expectedAfterSingleLine());
  tr.notOk("a { background-size: 0,\t0; }", _.messages.expectedAfterSingleLine());

  tr.ok("a::before { content: \"foo,bar,baz\"; }", "strings");
  tr.ok("a { transform: translate(1,1); }", "function arguments");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 ,0; }");
  tr.ok("a { background-size: 0,0; }");
  tr.ok("a { background-size: 0,0;\n}", "single-line list, multi-line block");
  tr.ok("a { background-size: 0,0;\r\n}", "single-line list, multi-line block with CRLF");
  tr.ok("a { background-size: 0\n,  0}", "ignores multi-line values");
  tr.ok("a { background-size: 0\r\n,  0}", "ignores multi-line values with CRLF");

  tr.notOk("a { background-size: 0, 0; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { background-size: 0, 0;\n}", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { background-size: 0, 0;\r\n}", _.messages.rejectedAfterSingleLine(), "CRLF");
  tr.notOk("a { background-size: 0,  0; }", _.messages.rejectedAfterSingleLine());
  tr.notOk("a { background-size: 0,\t0; }", _.messages.rejectedAfterSingleLine());

  tr.ok("a::before { content: \"foo, bar, baz\"; }", "strings");
  tr.ok("a { transform: translate(1, 1); }", "function arguments");
});