"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testRule = (0, _testUtils.ruleTester)(_2["default"], _.ruleName);

testRule("always", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 , 0; }");
  tr.ok("a { background-size: 0 ,0; }");
  tr.notOk("a { background-size: 0, 0; }", _.messages.expectedBefore());
  tr.notOk("a { background-size: 0  , 0; }", _.messages.expectedBefore());
  tr.notOk("a { background-size: 0\n, 0; }", _.messages.expectedBefore());
  tr.notOk("a { background-size: 0\r\n, 0; }", _.messages.expectedBefore(), "CRLF");
  tr.notOk("a { background-size: 0\t, 0; }", _.messages.expectedBefore());

  tr.ok("a::before { content: \"foo,bar,baz\"; }", "strings");
  tr.ok("a { transform: translate(1,1); }", "function arguments");
});

testRule("never", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0, 0; }");
  tr.ok("a { background-size: 0,0; }");
  tr.notOk("a { background-size: 0 , 0; }", _.messages.rejectedBefore());
  tr.notOk("a { background-size: 0  , 0; }", _.messages.rejectedBefore());
  tr.notOk("a { background-size: 0\n, 0; }", _.messages.rejectedBefore());
  tr.notOk("a { background-size: 0\r\n, 0; }", _.messages.rejectedBefore(), "CRLF");
  tr.notOk("a { background-size: 0\t, 0; }", _.messages.rejectedBefore());

  tr.ok("a::before { content: \"foo ,bar ,baz\"; }", "strings");
  tr.ok("a { transform: translate(1 ,1); }", "function arguments");
});

testRule("always-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0 , 0; }");
  tr.ok("a { background-size: 0 ,0; }");
  tr.ok("a { background-size: 0 ,0;\n}", "single-line list, multi-line block");
  tr.ok("a { background-size: 0 ,0;\r\n}", "single-line list, multi-line block with CRLF");
  tr.ok("a { background-size: 0,\n0; }", "ignores multi-line list");
  tr.ok("a { background-size: 0,\r\n0; }", "ignores multi-line list with CRLF");

  tr.notOk("a { background-size: 0, 0; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { background-size: 0, 0;\n}", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { background-size: 0, 0;\r\n}", _.messages.expectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { background-size: 0  , 0; }", _.messages.expectedBeforeSingleLine());
  tr.notOk("a { background-size: 0\t, 0; }", _.messages.expectedBeforeSingleLine());

  tr.ok("a::before { content: \"foo,bar,baz\"; }", "strings");
  tr.ok("a { transform: translate(1,1); }", "function arguments");
});

testRule("never-single-line", function (tr) {
  (0, _testUtils.warningFreeBasics)(tr);

  tr.ok("a { background-size: 0, 0; }");
  tr.ok("a { background-size: 0,0; }");
  tr.ok("a { background-size: 0,0;\n}", "single-line list, multi-line block");
  tr.ok("a { background-size: 0,0;\r\n}", "single-line list, multi-line block with CRLF");
  tr.ok("a { background-size: 0 ,\n0; }", "ignores multi-line list");
  tr.ok("a { background-size: 0 ,\r\n0; }", "ignores multi-line list with CRLF");

  tr.notOk("a { background-size: 0 , 0; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { background-size: 0 , 0;\n}", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { background-size: 0 , 0;\r\n}", _.messages.rejectedBeforeSingleLine(), "CRLF");
  tr.notOk("a { background-size: 0  , 0; }", _.messages.rejectedBeforeSingleLine());
  tr.notOk("a { background-size: 0\t, 0; }", _.messages.rejectedBeforeSingleLine());

  tr.ok("a::before { content: \"foo ,bar ,baz\"; }", "strings");
  tr.ok("a { transform: translate(1 ,1); }", "function arguments");
});