import {
  ruleTester,
  warningFreeBasics
} from "../../../testUtils"
import rule, { ruleName, messages } from ".."

const testRule = ruleTester(rule, ruleName)

testRule("always", tr => {
  warningFreeBasics(tr)

  tr.ok("@import url(x.css)")
  tr.ok("a { color: pink; }")
  tr.ok("@media print { a { color: pink; } }")

  tr.notOk("a {color: pink; }", messages.expectedAfter())
  tr.notOk("a {  color: pink; }", messages.expectedAfter())
  tr.notOk("a {\tcolor: pink; }", messages.expectedAfter())
  tr.notOk("a {\ncolor: pink; }", messages.expectedAfter())
  tr.notOk("a {\r\ncolor: pink; }", messages.expectedAfter(), "CRLF")
  tr.notOk("@media print {\na { color: pink; } }", messages.expectedAfter())
  tr.notOk("@media print { a {\ncolor: pink; } }", messages.expectedAfter())
  tr.notOk("@media print { a {\r\ncolor: pink; } }", messages.expectedAfter(), "CRLF")
})

testRule("never", tr => {
  warningFreeBasics(tr)

  tr.ok("a {color: pink; }")
  tr.ok("@media print {a {color: pink; } }")

  tr.notOk("a { color: pink; }", messages.rejectedAfter())
  tr.notOk("a {  color: pink; }", messages.rejectedAfter())
  tr.notOk("a {\tcolor: pink; }", messages.rejectedAfter())
  tr.notOk("a {\ncolor: pink; }", messages.rejectedAfter())
  tr.notOk("a {\r\ncolor: pink; }", messages.rejectedAfter(), "CRLF")
  tr.notOk("@media print {\na {color: pink; } }", messages.rejectedAfter())
  tr.notOk("@media print {a {\ncolor: pink; } }", messages.rejectedAfter())
})

testRule("always-single-line", tr => {
  warningFreeBasics(tr)

  // Regular "always" tests
  tr.ok("a { color: pink; }")
  tr.ok("@media print { a { color: pink; } }")

  tr.notOk("a {color: pink; }", messages.expectedAfterSingleLine())
  tr.notOk("a {  color: pink; }", messages.expectedAfterSingleLine())
  tr.notOk("a {\tcolor: pink; }", messages.expectedAfterSingleLine())
  tr.notOk("@media print {\ta { color: pink; } }", messages.expectedAfterSingleLine())
  tr.notOk("@media print { a {\tcolor: pink; } }", messages.expectedAfterSingleLine())

  // Ignoring multi-line blocks
  tr.ok("a {\ncolor: pink; }")
  tr.ok("a {\r\ncolor: pink; }", "CRLF")
  tr.ok("a {color:\npink; }")
  tr.ok("@media print {a {color:\npink; } }")
  tr.ok("@media print{a {color:\npink; } }")
})

testRule("never-single-line", tr => {
  warningFreeBasics(tr)

  // Regular "never" tests
  tr.ok("a {color: pink; }")
  tr.ok("@media print {a {color: pink; } }")

  tr.notOk("a { color: pink; }", messages.rejectedAfterSingleLine())
  tr.notOk("a {  color: pink; }", messages.rejectedAfterSingleLine())
  tr.notOk("a {\tcolor: pink; }", messages.rejectedAfterSingleLine())
  tr.notOk("@media print { a {color: pink; } }", messages.rejectedAfterSingleLine())
  tr.notOk("@media print {a { color: pink; } }", messages.rejectedAfterSingleLine())

  // Ignoring multi-line blocks
  tr.ok("a { color:\npink; }")
  tr.ok("@media print { a { color:\npink; } }")
  tr.ok("@media print { a\n{color: pink; } }")
  tr.ok("@media print { a\r\n{color: pink; } }", "CRLF")
})

testRule("always-multi-line", tr => {
  warningFreeBasics(tr)

  tr.ok("a { color: pink;\nbackground: orange; }")
  tr.ok("@media print { a { color: pink;\nbackground: orange } }")

  // Ignoring single-line blocks
  tr.ok("a {color: pink; }")
  tr.ok("@media print {a {color: pink; } }")
  tr.ok("a { color: pink; }")
  tr.ok("a {  color: pink; }")
  tr.ok("a {\tcolor: pink; }")

  tr.notOk("a {color: pink;\nbackground: orange; }", messages.expectedAfterMultiLine())
  tr.notOk("a {  color: pink;\nbackground: orange; }", messages.expectedAfterMultiLine())
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", messages.expectedAfterMultiLine())
  tr.notOk("a {\ncolor: pink;\nbackground: orange; }", messages.expectedAfterMultiLine())
  tr.notOk("a {\r\ncolor: pink;\r\nbackground: orange; }", messages.expectedAfterMultiLine(), "CRLF")
  tr.notOk("@media print\n{a { color: pink;\nbackground: orange; } }", messages.expectedAfterMultiLine())
  tr.notOk("@media print { a\n{color: pink;\nbackground: orange; } }", messages.expectedAfterMultiLine())
})

testRule("never-multi-line", tr => {
  warningFreeBasics(tr)

  tr.ok("a {color: pink;\nbackground: orange; }")
  tr.ok("@media print {a\n{color: pink;\nbackground: orange } }")
  tr.ok("@media print {a\r\n{color: pink;\r\nbackground: orange } }", "CRLF")

  // Ignoring single-line blocks
  tr.ok("a { color: pink; }")
  tr.ok("@media print { a { color: pink; } }")
  tr.ok("a { color: pink; }")
  tr.ok("a {  color: pink; }")
  tr.ok("a {\tcolor: pink; }")

  tr.notOk("a { color: pink;\nbackground: orange; }", messages.rejectedAfterMultiLine())
  tr.notOk("a {  color: pink;\nbackground: orange; }", messages.rejectedAfterMultiLine())
  tr.notOk("a {\tcolor: pink;\nbackground: orange; }", messages.rejectedAfterMultiLine())
  tr.notOk("a {\tcolor: pink;\r\nbackground: orange; }", messages.rejectedAfterMultiLine(), "CRLF")
  tr.notOk("a {\ncolor: pink;\nbackground: orange; }", messages.rejectedAfterMultiLine())
  tr.notOk("@media print\n{ a {color: pink;\nbackground: orange; } }", messages.rejectedAfterMultiLine())
  tr.notOk("@media print{a\n{ color: pink;\nbackground: orange; } }", messages.rejectedAfterMultiLine())
})
